from enum import Enum
import math
import string


class MolarMassUnits(Enum):
        """
            MolarMassUnits enumeration
        """
        
        GramPerMole = 'gram_per_mole'
        """
            
        """
        
        KilogramPerKilomole = 'kilogram_per_kilomole'
        """
            
        """
        
        PoundPerMole = 'pound_per_mole'
        """
            
        """
        
        NanogramPerMole = 'nanogram_per_mole'
        """
            
        """
        
        MicrogramPerMole = 'microgram_per_mole'
        """
            
        """
        
        MilligramPerMole = 'milligram_per_mole'
        """
            
        """
        
        CentigramPerMole = 'centigram_per_mole'
        """
            
        """
        
        DecigramPerMole = 'decigram_per_mole'
        """
            
        """
        
        DecagramPerMole = 'decagram_per_mole'
        """
            
        """
        
        HectogramPerMole = 'hectogram_per_mole'
        """
            
        """
        
        KilogramPerMole = 'kilogram_per_mole'
        """
            
        """
        
        KilopoundPerMole = 'kilopound_per_mole'
        """
            
        """
        
        MegapoundPerMole = 'megapound_per_mole'
        """
            
        """
        

class MolarMass:
    """
    In chemistry, the molar mass M is a physical property defined as the mass of a given substance (chemical element or chemical compound) divided by the amount of substance.

    Args:
        value (float): The value.
        from_unit (MolarMassUnits): The MolarMass unit to create from, The default unit is KilogramPerMole
    """
    def __init__(self, value: float, from_unit: MolarMassUnits = MolarMassUnits.KilogramPerMole):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__grams_per_mole = None
        
        self.__kilograms_per_kilomole = None
        
        self.__pounds_per_mole = None
        
        self.__nanograms_per_mole = None
        
        self.__micrograms_per_mole = None
        
        self.__milligrams_per_mole = None
        
        self.__centigrams_per_mole = None
        
        self.__decigrams_per_mole = None
        
        self.__decagrams_per_mole = None
        
        self.__hectograms_per_mole = None
        
        self.__kilograms_per_mole = None
        
        self.__kilopounds_per_mole = None
        
        self.__megapounds_per_mole = None
        

    def __convert_from_base(self, from_unit: MolarMassUnits) -> float:
        value = self.__value
        
        if from_unit == MolarMassUnits.GramPerMole:
            return (value * 1e3)
        
        if from_unit == MolarMassUnits.KilogramPerKilomole:
            return (value * 1e3)
        
        if from_unit == MolarMassUnits.PoundPerMole:
            return (value / 0.45359237)
        
        if from_unit == MolarMassUnits.NanogramPerMole:
            return ((value * 1e3) / 1e-09)
        
        if from_unit == MolarMassUnits.MicrogramPerMole:
            return ((value * 1e3) / 1e-06)
        
        if from_unit == MolarMassUnits.MilligramPerMole:
            return ((value * 1e3) / 0.001)
        
        if from_unit == MolarMassUnits.CentigramPerMole:
            return ((value * 1e3) / 0.01)
        
        if from_unit == MolarMassUnits.DecigramPerMole:
            return ((value * 1e3) / 0.1)
        
        if from_unit == MolarMassUnits.DecagramPerMole:
            return ((value * 1e3) / 10.0)
        
        if from_unit == MolarMassUnits.HectogramPerMole:
            return ((value * 1e3) / 100.0)
        
        if from_unit == MolarMassUnits.KilogramPerMole:
            return ((value * 1e3) / 1000.0)
        
        if from_unit == MolarMassUnits.KilopoundPerMole:
            return ((value / 0.45359237) / 1000.0)
        
        if from_unit == MolarMassUnits.MegapoundPerMole:
            return ((value / 0.45359237) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: MolarMassUnits) -> float:
        
        if to_unit == MolarMassUnits.GramPerMole:
            return (value / 1e3)
        
        if to_unit == MolarMassUnits.KilogramPerKilomole:
            return (value / 1e3)
        
        if to_unit == MolarMassUnits.PoundPerMole:
            return (value * 0.45359237)
        
        if to_unit == MolarMassUnits.NanogramPerMole:
            return ((value / 1e3) * 1e-09)
        
        if to_unit == MolarMassUnits.MicrogramPerMole:
            return ((value / 1e3) * 1e-06)
        
        if to_unit == MolarMassUnits.MilligramPerMole:
            return ((value / 1e3) * 0.001)
        
        if to_unit == MolarMassUnits.CentigramPerMole:
            return ((value / 1e3) * 0.01)
        
        if to_unit == MolarMassUnits.DecigramPerMole:
            return ((value / 1e3) * 0.1)
        
        if to_unit == MolarMassUnits.DecagramPerMole:
            return ((value / 1e3) * 10.0)
        
        if to_unit == MolarMassUnits.HectogramPerMole:
            return ((value / 1e3) * 100.0)
        
        if to_unit == MolarMassUnits.KilogramPerMole:
            return ((value / 1e3) * 1000.0)
        
        if to_unit == MolarMassUnits.KilopoundPerMole:
            return ((value * 0.45359237) * 1000.0)
        
        if to_unit == MolarMassUnits.MegapoundPerMole:
            return ((value * 0.45359237) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_grams_per_mole(grams_per_mole: float):
        """
        Create a new instance of MolarMass from a value in grams_per_mole.

        

        :param meters: The MolarMass value in grams_per_mole.
        :type grams_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(grams_per_mole, MolarMassUnits.GramPerMole)

    
    @staticmethod
    def from_kilograms_per_kilomole(kilograms_per_kilomole: float):
        """
        Create a new instance of MolarMass from a value in kilograms_per_kilomole.

        

        :param meters: The MolarMass value in kilograms_per_kilomole.
        :type kilograms_per_kilomole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(kilograms_per_kilomole, MolarMassUnits.KilogramPerKilomole)

    
    @staticmethod
    def from_pounds_per_mole(pounds_per_mole: float):
        """
        Create a new instance of MolarMass from a value in pounds_per_mole.

        

        :param meters: The MolarMass value in pounds_per_mole.
        :type pounds_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(pounds_per_mole, MolarMassUnits.PoundPerMole)

    
    @staticmethod
    def from_nanograms_per_mole(nanograms_per_mole: float):
        """
        Create a new instance of MolarMass from a value in nanograms_per_mole.

        

        :param meters: The MolarMass value in nanograms_per_mole.
        :type nanograms_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(nanograms_per_mole, MolarMassUnits.NanogramPerMole)

    
    @staticmethod
    def from_micrograms_per_mole(micrograms_per_mole: float):
        """
        Create a new instance of MolarMass from a value in micrograms_per_mole.

        

        :param meters: The MolarMass value in micrograms_per_mole.
        :type micrograms_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(micrograms_per_mole, MolarMassUnits.MicrogramPerMole)

    
    @staticmethod
    def from_milligrams_per_mole(milligrams_per_mole: float):
        """
        Create a new instance of MolarMass from a value in milligrams_per_mole.

        

        :param meters: The MolarMass value in milligrams_per_mole.
        :type milligrams_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(milligrams_per_mole, MolarMassUnits.MilligramPerMole)

    
    @staticmethod
    def from_centigrams_per_mole(centigrams_per_mole: float):
        """
        Create a new instance of MolarMass from a value in centigrams_per_mole.

        

        :param meters: The MolarMass value in centigrams_per_mole.
        :type centigrams_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(centigrams_per_mole, MolarMassUnits.CentigramPerMole)

    
    @staticmethod
    def from_decigrams_per_mole(decigrams_per_mole: float):
        """
        Create a new instance of MolarMass from a value in decigrams_per_mole.

        

        :param meters: The MolarMass value in decigrams_per_mole.
        :type decigrams_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(decigrams_per_mole, MolarMassUnits.DecigramPerMole)

    
    @staticmethod
    def from_decagrams_per_mole(decagrams_per_mole: float):
        """
        Create a new instance of MolarMass from a value in decagrams_per_mole.

        

        :param meters: The MolarMass value in decagrams_per_mole.
        :type decagrams_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(decagrams_per_mole, MolarMassUnits.DecagramPerMole)

    
    @staticmethod
    def from_hectograms_per_mole(hectograms_per_mole: float):
        """
        Create a new instance of MolarMass from a value in hectograms_per_mole.

        

        :param meters: The MolarMass value in hectograms_per_mole.
        :type hectograms_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(hectograms_per_mole, MolarMassUnits.HectogramPerMole)

    
    @staticmethod
    def from_kilograms_per_mole(kilograms_per_mole: float):
        """
        Create a new instance of MolarMass from a value in kilograms_per_mole.

        

        :param meters: The MolarMass value in kilograms_per_mole.
        :type kilograms_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(kilograms_per_mole, MolarMassUnits.KilogramPerMole)

    
    @staticmethod
    def from_kilopounds_per_mole(kilopounds_per_mole: float):
        """
        Create a new instance of MolarMass from a value in kilopounds_per_mole.

        

        :param meters: The MolarMass value in kilopounds_per_mole.
        :type kilopounds_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(kilopounds_per_mole, MolarMassUnits.KilopoundPerMole)

    
    @staticmethod
    def from_megapounds_per_mole(megapounds_per_mole: float):
        """
        Create a new instance of MolarMass from a value in megapounds_per_mole.

        

        :param meters: The MolarMass value in megapounds_per_mole.
        :type megapounds_per_mole: float
        :return: A new instance of MolarMass.
        :rtype: MolarMass
        """
        return MolarMass(megapounds_per_mole, MolarMassUnits.MegapoundPerMole)

    
    @property
    def grams_per_mole(self) -> float:
        """
        
        """
        if self.__grams_per_mole != None:
            return self.__grams_per_mole
        self.__grams_per_mole = self.__convert_from_base(MolarMassUnits.GramPerMole)
        return self.__grams_per_mole

    
    @property
    def kilograms_per_kilomole(self) -> float:
        """
        
        """
        if self.__kilograms_per_kilomole != None:
            return self.__kilograms_per_kilomole
        self.__kilograms_per_kilomole = self.__convert_from_base(MolarMassUnits.KilogramPerKilomole)
        return self.__kilograms_per_kilomole

    
    @property
    def pounds_per_mole(self) -> float:
        """
        
        """
        if self.__pounds_per_mole != None:
            return self.__pounds_per_mole
        self.__pounds_per_mole = self.__convert_from_base(MolarMassUnits.PoundPerMole)
        return self.__pounds_per_mole

    
    @property
    def nanograms_per_mole(self) -> float:
        """
        
        """
        if self.__nanograms_per_mole != None:
            return self.__nanograms_per_mole
        self.__nanograms_per_mole = self.__convert_from_base(MolarMassUnits.NanogramPerMole)
        return self.__nanograms_per_mole

    
    @property
    def micrograms_per_mole(self) -> float:
        """
        
        """
        if self.__micrograms_per_mole != None:
            return self.__micrograms_per_mole
        self.__micrograms_per_mole = self.__convert_from_base(MolarMassUnits.MicrogramPerMole)
        return self.__micrograms_per_mole

    
    @property
    def milligrams_per_mole(self) -> float:
        """
        
        """
        if self.__milligrams_per_mole != None:
            return self.__milligrams_per_mole
        self.__milligrams_per_mole = self.__convert_from_base(MolarMassUnits.MilligramPerMole)
        return self.__milligrams_per_mole

    
    @property
    def centigrams_per_mole(self) -> float:
        """
        
        """
        if self.__centigrams_per_mole != None:
            return self.__centigrams_per_mole
        self.__centigrams_per_mole = self.__convert_from_base(MolarMassUnits.CentigramPerMole)
        return self.__centigrams_per_mole

    
    @property
    def decigrams_per_mole(self) -> float:
        """
        
        """
        if self.__decigrams_per_mole != None:
            return self.__decigrams_per_mole
        self.__decigrams_per_mole = self.__convert_from_base(MolarMassUnits.DecigramPerMole)
        return self.__decigrams_per_mole

    
    @property
    def decagrams_per_mole(self) -> float:
        """
        
        """
        if self.__decagrams_per_mole != None:
            return self.__decagrams_per_mole
        self.__decagrams_per_mole = self.__convert_from_base(MolarMassUnits.DecagramPerMole)
        return self.__decagrams_per_mole

    
    @property
    def hectograms_per_mole(self) -> float:
        """
        
        """
        if self.__hectograms_per_mole != None:
            return self.__hectograms_per_mole
        self.__hectograms_per_mole = self.__convert_from_base(MolarMassUnits.HectogramPerMole)
        return self.__hectograms_per_mole

    
    @property
    def kilograms_per_mole(self) -> float:
        """
        
        """
        if self.__kilograms_per_mole != None:
            return self.__kilograms_per_mole
        self.__kilograms_per_mole = self.__convert_from_base(MolarMassUnits.KilogramPerMole)
        return self.__kilograms_per_mole

    
    @property
    def kilopounds_per_mole(self) -> float:
        """
        
        """
        if self.__kilopounds_per_mole != None:
            return self.__kilopounds_per_mole
        self.__kilopounds_per_mole = self.__convert_from_base(MolarMassUnits.KilopoundPerMole)
        return self.__kilopounds_per_mole

    
    @property
    def megapounds_per_mole(self) -> float:
        """
        
        """
        if self.__megapounds_per_mole != None:
            return self.__megapounds_per_mole
        self.__megapounds_per_mole = self.__convert_from_base(MolarMassUnits.MegapoundPerMole)
        return self.__megapounds_per_mole

    
    def to_string(self, unit: MolarMassUnits = MolarMassUnits.KilogramPerMole) -> string:
        """
        Format the MolarMass to string.
        Note! the default format for MolarMass is KilogramPerMole.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == MolarMassUnits.GramPerMole:
            return f"""{self.grams_per_mole} g/mol"""
        
        if unit == MolarMassUnits.KilogramPerKilomole:
            return f"""{self.kilograms_per_kilomole} kg/kmol"""
        
        if unit == MolarMassUnits.PoundPerMole:
            return f"""{self.pounds_per_mole} lb/mol"""
        
        if unit == MolarMassUnits.NanogramPerMole:
            return f"""{self.nanograms_per_mole} """
        
        if unit == MolarMassUnits.MicrogramPerMole:
            return f"""{self.micrograms_per_mole} """
        
        if unit == MolarMassUnits.MilligramPerMole:
            return f"""{self.milligrams_per_mole} """
        
        if unit == MolarMassUnits.CentigramPerMole:
            return f"""{self.centigrams_per_mole} """
        
        if unit == MolarMassUnits.DecigramPerMole:
            return f"""{self.decigrams_per_mole} """
        
        if unit == MolarMassUnits.DecagramPerMole:
            return f"""{self.decagrams_per_mole} """
        
        if unit == MolarMassUnits.HectogramPerMole:
            return f"""{self.hectograms_per_mole} """
        
        if unit == MolarMassUnits.KilogramPerMole:
            return f"""{self.kilograms_per_mole} """
        
        if unit == MolarMassUnits.KilopoundPerMole:
            return f"""{self.kilopounds_per_mole} """
        
        if unit == MolarMassUnits.MegapoundPerMole:
            return f"""{self.megapounds_per_mole} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: MolarMassUnits = MolarMassUnits.KilogramPerMole) -> string:
        """
        Get MolarMass unit abbreviation.
        Note! the default abbreviation for MolarMass is KilogramPerMole.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == MolarMassUnits.GramPerMole:
            return """g/mol"""
        
        if unit_abbreviation == MolarMassUnits.KilogramPerKilomole:
            return """kg/kmol"""
        
        if unit_abbreviation == MolarMassUnits.PoundPerMole:
            return """lb/mol"""
        
        if unit_abbreviation == MolarMassUnits.NanogramPerMole:
            return """"""
        
        if unit_abbreviation == MolarMassUnits.MicrogramPerMole:
            return """"""
        
        if unit_abbreviation == MolarMassUnits.MilligramPerMole:
            return """"""
        
        if unit_abbreviation == MolarMassUnits.CentigramPerMole:
            return """"""
        
        if unit_abbreviation == MolarMassUnits.DecigramPerMole:
            return """"""
        
        if unit_abbreviation == MolarMassUnits.DecagramPerMole:
            return """"""
        
        if unit_abbreviation == MolarMassUnits.HectogramPerMole:
            return """"""
        
        if unit_abbreviation == MolarMassUnits.KilogramPerMole:
            return """"""
        
        if unit_abbreviation == MolarMassUnits.KilopoundPerMole:
            return """"""
        
        if unit_abbreviation == MolarMassUnits.MegapoundPerMole:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for +: 'MolarMass' and '{}'".format(type(other).__name__))
        return MolarMass(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for *: 'MolarMass' and '{}'".format(type(other).__name__))
        return MolarMass(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for -: 'MolarMass' and '{}'".format(type(other).__name__))
        return MolarMass(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for /: 'MolarMass' and '{}'".format(type(other).__name__))
        return MolarMass(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for %: 'MolarMass' and '{}'".format(type(other).__name__))
        return MolarMass(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for **: 'MolarMass' and '{}'".format(type(other).__name__))
        return MolarMass(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for ==: 'MolarMass' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for <: 'MolarMass' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for >: 'MolarMass' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for <=: 'MolarMass' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, MolarMass):
            raise TypeError("unsupported operand type(s) for >=: 'MolarMass' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class LuminanceUnits(Enum):
        """
            LuminanceUnits enumeration
        """
        
        CandelaPerSquareMeter = 'candela_per_square_meter'
        """
            
        """
        
        CandelaPerSquareFoot = 'candela_per_square_foot'
        """
            
        """
        
        CandelaPerSquareInch = 'candela_per_square_inch'
        """
            
        """
        
        Nit = 'nit'
        """
            
        """
        
        NanocandelaPerSquareMeter = 'nanocandela_per_square_meter'
        """
            
        """
        
        MicrocandelaPerSquareMeter = 'microcandela_per_square_meter'
        """
            
        """
        
        MillicandelaPerSquareMeter = 'millicandela_per_square_meter'
        """
            
        """
        
        CenticandelaPerSquareMeter = 'centicandela_per_square_meter'
        """
            
        """
        
        DecicandelaPerSquareMeter = 'decicandela_per_square_meter'
        """
            
        """
        
        KilocandelaPerSquareMeter = 'kilocandela_per_square_meter'
        """
            
        """
        

class Luminance:
    """
    None

    Args:
        value (float): The value.
        from_unit (LuminanceUnits): The Luminance unit to create from, The default unit is CandelaPerSquareMeter
    """
    def __init__(self, value: float, from_unit: LuminanceUnits = LuminanceUnits.CandelaPerSquareMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__candelas_per_square_meter = None
        
        self.__candelas_per_square_foot = None
        
        self.__candelas_per_square_inch = None
        
        self.__nits = None
        
        self.__nanocandelas_per_square_meter = None
        
        self.__microcandelas_per_square_meter = None
        
        self.__millicandelas_per_square_meter = None
        
        self.__centicandelas_per_square_meter = None
        
        self.__decicandelas_per_square_meter = None
        
        self.__kilocandelas_per_square_meter = None
        

    def __convert_from_base(self, from_unit: LuminanceUnits) -> float:
        value = self.__value
        
        if from_unit == LuminanceUnits.CandelaPerSquareMeter:
            return (value)
        
        if from_unit == LuminanceUnits.CandelaPerSquareFoot:
            return (value/ 1.07639e1)
        
        if from_unit == LuminanceUnits.CandelaPerSquareInch:
            return (value/ 1.5500031e3)
        
        if from_unit == LuminanceUnits.Nit:
            return (value)
        
        if from_unit == LuminanceUnits.NanocandelaPerSquareMeter:
            return ((value) / 1e-09)
        
        if from_unit == LuminanceUnits.MicrocandelaPerSquareMeter:
            return ((value) / 1e-06)
        
        if from_unit == LuminanceUnits.MillicandelaPerSquareMeter:
            return ((value) / 0.001)
        
        if from_unit == LuminanceUnits.CenticandelaPerSquareMeter:
            return ((value) / 0.01)
        
        if from_unit == LuminanceUnits.DecicandelaPerSquareMeter:
            return ((value) / 0.1)
        
        if from_unit == LuminanceUnits.KilocandelaPerSquareMeter:
            return ((value) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: LuminanceUnits) -> float:
        
        if to_unit == LuminanceUnits.CandelaPerSquareMeter:
            return (value)
        
        if to_unit == LuminanceUnits.CandelaPerSquareFoot:
            return (value* 1.07639e1)
        
        if to_unit == LuminanceUnits.CandelaPerSquareInch:
            return (value* 1.5500031e3)
        
        if to_unit == LuminanceUnits.Nit:
            return (value)
        
        if to_unit == LuminanceUnits.NanocandelaPerSquareMeter:
            return ((value) * 1e-09)
        
        if to_unit == LuminanceUnits.MicrocandelaPerSquareMeter:
            return ((value) * 1e-06)
        
        if to_unit == LuminanceUnits.MillicandelaPerSquareMeter:
            return ((value) * 0.001)
        
        if to_unit == LuminanceUnits.CenticandelaPerSquareMeter:
            return ((value) * 0.01)
        
        if to_unit == LuminanceUnits.DecicandelaPerSquareMeter:
            return ((value) * 0.1)
        
        if to_unit == LuminanceUnits.KilocandelaPerSquareMeter:
            return ((value) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_candelas_per_square_meter(candelas_per_square_meter: float):
        """
        Create a new instance of Luminance from a value in candelas_per_square_meter.

        

        :param meters: The Luminance value in candelas_per_square_meter.
        :type candelas_per_square_meter: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(candelas_per_square_meter, LuminanceUnits.CandelaPerSquareMeter)

    
    @staticmethod
    def from_candelas_per_square_foot(candelas_per_square_foot: float):
        """
        Create a new instance of Luminance from a value in candelas_per_square_foot.

        

        :param meters: The Luminance value in candelas_per_square_foot.
        :type candelas_per_square_foot: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(candelas_per_square_foot, LuminanceUnits.CandelaPerSquareFoot)

    
    @staticmethod
    def from_candelas_per_square_inch(candelas_per_square_inch: float):
        """
        Create a new instance of Luminance from a value in candelas_per_square_inch.

        

        :param meters: The Luminance value in candelas_per_square_inch.
        :type candelas_per_square_inch: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(candelas_per_square_inch, LuminanceUnits.CandelaPerSquareInch)

    
    @staticmethod
    def from_nits(nits: float):
        """
        Create a new instance of Luminance from a value in nits.

        

        :param meters: The Luminance value in nits.
        :type nits: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(nits, LuminanceUnits.Nit)

    
    @staticmethod
    def from_nanocandelas_per_square_meter(nanocandelas_per_square_meter: float):
        """
        Create a new instance of Luminance from a value in nanocandelas_per_square_meter.

        

        :param meters: The Luminance value in nanocandelas_per_square_meter.
        :type nanocandelas_per_square_meter: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(nanocandelas_per_square_meter, LuminanceUnits.NanocandelaPerSquareMeter)

    
    @staticmethod
    def from_microcandelas_per_square_meter(microcandelas_per_square_meter: float):
        """
        Create a new instance of Luminance from a value in microcandelas_per_square_meter.

        

        :param meters: The Luminance value in microcandelas_per_square_meter.
        :type microcandelas_per_square_meter: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(microcandelas_per_square_meter, LuminanceUnits.MicrocandelaPerSquareMeter)

    
    @staticmethod
    def from_millicandelas_per_square_meter(millicandelas_per_square_meter: float):
        """
        Create a new instance of Luminance from a value in millicandelas_per_square_meter.

        

        :param meters: The Luminance value in millicandelas_per_square_meter.
        :type millicandelas_per_square_meter: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(millicandelas_per_square_meter, LuminanceUnits.MillicandelaPerSquareMeter)

    
    @staticmethod
    def from_centicandelas_per_square_meter(centicandelas_per_square_meter: float):
        """
        Create a new instance of Luminance from a value in centicandelas_per_square_meter.

        

        :param meters: The Luminance value in centicandelas_per_square_meter.
        :type centicandelas_per_square_meter: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(centicandelas_per_square_meter, LuminanceUnits.CenticandelaPerSquareMeter)

    
    @staticmethod
    def from_decicandelas_per_square_meter(decicandelas_per_square_meter: float):
        """
        Create a new instance of Luminance from a value in decicandelas_per_square_meter.

        

        :param meters: The Luminance value in decicandelas_per_square_meter.
        :type decicandelas_per_square_meter: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(decicandelas_per_square_meter, LuminanceUnits.DecicandelaPerSquareMeter)

    
    @staticmethod
    def from_kilocandelas_per_square_meter(kilocandelas_per_square_meter: float):
        """
        Create a new instance of Luminance from a value in kilocandelas_per_square_meter.

        

        :param meters: The Luminance value in kilocandelas_per_square_meter.
        :type kilocandelas_per_square_meter: float
        :return: A new instance of Luminance.
        :rtype: Luminance
        """
        return Luminance(kilocandelas_per_square_meter, LuminanceUnits.KilocandelaPerSquareMeter)

    
    @property
    def candelas_per_square_meter(self) -> float:
        """
        
        """
        if self.__candelas_per_square_meter != None:
            return self.__candelas_per_square_meter
        self.__candelas_per_square_meter = self.__convert_from_base(LuminanceUnits.CandelaPerSquareMeter)
        return self.__candelas_per_square_meter

    
    @property
    def candelas_per_square_foot(self) -> float:
        """
        
        """
        if self.__candelas_per_square_foot != None:
            return self.__candelas_per_square_foot
        self.__candelas_per_square_foot = self.__convert_from_base(LuminanceUnits.CandelaPerSquareFoot)
        return self.__candelas_per_square_foot

    
    @property
    def candelas_per_square_inch(self) -> float:
        """
        
        """
        if self.__candelas_per_square_inch != None:
            return self.__candelas_per_square_inch
        self.__candelas_per_square_inch = self.__convert_from_base(LuminanceUnits.CandelaPerSquareInch)
        return self.__candelas_per_square_inch

    
    @property
    def nits(self) -> float:
        """
        
        """
        if self.__nits != None:
            return self.__nits
        self.__nits = self.__convert_from_base(LuminanceUnits.Nit)
        return self.__nits

    
    @property
    def nanocandelas_per_square_meter(self) -> float:
        """
        
        """
        if self.__nanocandelas_per_square_meter != None:
            return self.__nanocandelas_per_square_meter
        self.__nanocandelas_per_square_meter = self.__convert_from_base(LuminanceUnits.NanocandelaPerSquareMeter)
        return self.__nanocandelas_per_square_meter

    
    @property
    def microcandelas_per_square_meter(self) -> float:
        """
        
        """
        if self.__microcandelas_per_square_meter != None:
            return self.__microcandelas_per_square_meter
        self.__microcandelas_per_square_meter = self.__convert_from_base(LuminanceUnits.MicrocandelaPerSquareMeter)
        return self.__microcandelas_per_square_meter

    
    @property
    def millicandelas_per_square_meter(self) -> float:
        """
        
        """
        if self.__millicandelas_per_square_meter != None:
            return self.__millicandelas_per_square_meter
        self.__millicandelas_per_square_meter = self.__convert_from_base(LuminanceUnits.MillicandelaPerSquareMeter)
        return self.__millicandelas_per_square_meter

    
    @property
    def centicandelas_per_square_meter(self) -> float:
        """
        
        """
        if self.__centicandelas_per_square_meter != None:
            return self.__centicandelas_per_square_meter
        self.__centicandelas_per_square_meter = self.__convert_from_base(LuminanceUnits.CenticandelaPerSquareMeter)
        return self.__centicandelas_per_square_meter

    
    @property
    def decicandelas_per_square_meter(self) -> float:
        """
        
        """
        if self.__decicandelas_per_square_meter != None:
            return self.__decicandelas_per_square_meter
        self.__decicandelas_per_square_meter = self.__convert_from_base(LuminanceUnits.DecicandelaPerSquareMeter)
        return self.__decicandelas_per_square_meter

    
    @property
    def kilocandelas_per_square_meter(self) -> float:
        """
        
        """
        if self.__kilocandelas_per_square_meter != None:
            return self.__kilocandelas_per_square_meter
        self.__kilocandelas_per_square_meter = self.__convert_from_base(LuminanceUnits.KilocandelaPerSquareMeter)
        return self.__kilocandelas_per_square_meter

    
    def to_string(self, unit: LuminanceUnits = LuminanceUnits.CandelaPerSquareMeter) -> string:
        """
        Format the Luminance to string.
        Note! the default format for Luminance is CandelaPerSquareMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == LuminanceUnits.CandelaPerSquareMeter:
            return f"""{self.candelas_per_square_meter} Cd/m²"""
        
        if unit == LuminanceUnits.CandelaPerSquareFoot:
            return f"""{self.candelas_per_square_foot} Cd/ft²"""
        
        if unit == LuminanceUnits.CandelaPerSquareInch:
            return f"""{self.candelas_per_square_inch} Cd/in²"""
        
        if unit == LuminanceUnits.Nit:
            return f"""{self.nits} nt"""
        
        if unit == LuminanceUnits.NanocandelaPerSquareMeter:
            return f"""{self.nanocandelas_per_square_meter} """
        
        if unit == LuminanceUnits.MicrocandelaPerSquareMeter:
            return f"""{self.microcandelas_per_square_meter} """
        
        if unit == LuminanceUnits.MillicandelaPerSquareMeter:
            return f"""{self.millicandelas_per_square_meter} """
        
        if unit == LuminanceUnits.CenticandelaPerSquareMeter:
            return f"""{self.centicandelas_per_square_meter} """
        
        if unit == LuminanceUnits.DecicandelaPerSquareMeter:
            return f"""{self.decicandelas_per_square_meter} """
        
        if unit == LuminanceUnits.KilocandelaPerSquareMeter:
            return f"""{self.kilocandelas_per_square_meter} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: LuminanceUnits = LuminanceUnits.CandelaPerSquareMeter) -> string:
        """
        Get Luminance unit abbreviation.
        Note! the default abbreviation for Luminance is CandelaPerSquareMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == LuminanceUnits.CandelaPerSquareMeter:
            return """Cd/m²"""
        
        if unit_abbreviation == LuminanceUnits.CandelaPerSquareFoot:
            return """Cd/ft²"""
        
        if unit_abbreviation == LuminanceUnits.CandelaPerSquareInch:
            return """Cd/in²"""
        
        if unit_abbreviation == LuminanceUnits.Nit:
            return """nt"""
        
        if unit_abbreviation == LuminanceUnits.NanocandelaPerSquareMeter:
            return """"""
        
        if unit_abbreviation == LuminanceUnits.MicrocandelaPerSquareMeter:
            return """"""
        
        if unit_abbreviation == LuminanceUnits.MillicandelaPerSquareMeter:
            return """"""
        
        if unit_abbreviation == LuminanceUnits.CenticandelaPerSquareMeter:
            return """"""
        
        if unit_abbreviation == LuminanceUnits.DecicandelaPerSquareMeter:
            return """"""
        
        if unit_abbreviation == LuminanceUnits.KilocandelaPerSquareMeter:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for +: 'Luminance' and '{}'".format(type(other).__name__))
        return Luminance(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for *: 'Luminance' and '{}'".format(type(other).__name__))
        return Luminance(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for -: 'Luminance' and '{}'".format(type(other).__name__))
        return Luminance(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for /: 'Luminance' and '{}'".format(type(other).__name__))
        return Luminance(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for %: 'Luminance' and '{}'".format(type(other).__name__))
        return Luminance(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for **: 'Luminance' and '{}'".format(type(other).__name__))
        return Luminance(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for ==: 'Luminance' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for <: 'Luminance' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for >: 'Luminance' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for <=: 'Luminance' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Luminance):
            raise TypeError("unsupported operand type(s) for >=: 'Luminance' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class VolumePerLengthUnits(Enum):
        """
            VolumePerLengthUnits enumeration
        """
        
        CubicMeterPerMeter = 'cubic_meter_per_meter'
        """
            
        """
        
        LiterPerMeter = 'liter_per_meter'
        """
            
        """
        
        LiterPerKilometer = 'liter_per_kilometer'
        """
            
        """
        
        LiterPerMillimeter = 'liter_per_millimeter'
        """
            
        """
        
        OilBarrelPerFoot = 'oil_barrel_per_foot'
        """
            
        """
        
        CubicYardPerFoot = 'cubic_yard_per_foot'
        """
            
        """
        
        CubicYardPerUsSurveyFoot = 'cubic_yard_per_us_survey_foot'
        """
            
        """
        
        UsGallonPerMile = 'us_gallon_per_mile'
        """
            
        """
        
        ImperialGallonPerMile = 'imperial_gallon_per_mile'
        """
            
        """
        

class VolumePerLength:
    """
    Volume, typically of fluid, that a container can hold within a unit of length.

    Args:
        value (float): The value.
        from_unit (VolumePerLengthUnits): The VolumePerLength unit to create from, The default unit is CubicMeterPerMeter
    """
    def __init__(self, value: float, from_unit: VolumePerLengthUnits = VolumePerLengthUnits.CubicMeterPerMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__cubic_meters_per_meter = None
        
        self.__liters_per_meter = None
        
        self.__liters_per_kilometer = None
        
        self.__liters_per_millimeter = None
        
        self.__oil_barrels_per_foot = None
        
        self.__cubic_yards_per_foot = None
        
        self.__cubic_yards_per_us_survey_foot = None
        
        self.__us_gallons_per_mile = None
        
        self.__imperial_gallons_per_mile = None
        

    def __convert_from_base(self, from_unit: VolumePerLengthUnits) -> float:
        value = self.__value
        
        if from_unit == VolumePerLengthUnits.CubicMeterPerMeter:
            return (value)
        
        if from_unit == VolumePerLengthUnits.LiterPerMeter:
            return (value * 1000)
        
        if from_unit == VolumePerLengthUnits.LiterPerKilometer:
            return (value * 1e6)
        
        if from_unit == VolumePerLengthUnits.LiterPerMillimeter:
            return (value)
        
        if from_unit == VolumePerLengthUnits.OilBarrelPerFoot:
            return (value * 1.91713408)
        
        if from_unit == VolumePerLengthUnits.CubicYardPerFoot:
            return (value / 2.50838208)
        
        if from_unit == VolumePerLengthUnits.CubicYardPerUsSurveyFoot:
            return (value / 2.50837706323584)
        
        if from_unit == VolumePerLengthUnits.UsGallonPerMile:
            return (value * (1000 * 1609.344 / 3.785411784))
        
        if from_unit == VolumePerLengthUnits.ImperialGallonPerMile:
            return (value * (1000 * 1609.344 / 4.54609))
        
        return None


    def __convert_to_base(self, value: float, to_unit: VolumePerLengthUnits) -> float:
        
        if to_unit == VolumePerLengthUnits.CubicMeterPerMeter:
            return (value)
        
        if to_unit == VolumePerLengthUnits.LiterPerMeter:
            return (value / 1000)
        
        if to_unit == VolumePerLengthUnits.LiterPerKilometer:
            return (value / 1e6)
        
        if to_unit == VolumePerLengthUnits.LiterPerMillimeter:
            return (value)
        
        if to_unit == VolumePerLengthUnits.OilBarrelPerFoot:
            return (value / 1.91713408)
        
        if to_unit == VolumePerLengthUnits.CubicYardPerFoot:
            return (value * 2.50838208)
        
        if to_unit == VolumePerLengthUnits.CubicYardPerUsSurveyFoot:
            return (value * 2.50837706323584)
        
        if to_unit == VolumePerLengthUnits.UsGallonPerMile:
            return (value / (1000 * 1609.344 / 3.785411784))
        
        if to_unit == VolumePerLengthUnits.ImperialGallonPerMile:
            return (value / (1000 * 1609.344 / 4.54609))
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_cubic_meters_per_meter(cubic_meters_per_meter: float):
        """
        Create a new instance of VolumePerLength from a value in cubic_meters_per_meter.

        

        :param meters: The VolumePerLength value in cubic_meters_per_meter.
        :type cubic_meters_per_meter: float
        :return: A new instance of VolumePerLength.
        :rtype: VolumePerLength
        """
        return VolumePerLength(cubic_meters_per_meter, VolumePerLengthUnits.CubicMeterPerMeter)

    
    @staticmethod
    def from_liters_per_meter(liters_per_meter: float):
        """
        Create a new instance of VolumePerLength from a value in liters_per_meter.

        

        :param meters: The VolumePerLength value in liters_per_meter.
        :type liters_per_meter: float
        :return: A new instance of VolumePerLength.
        :rtype: VolumePerLength
        """
        return VolumePerLength(liters_per_meter, VolumePerLengthUnits.LiterPerMeter)

    
    @staticmethod
    def from_liters_per_kilometer(liters_per_kilometer: float):
        """
        Create a new instance of VolumePerLength from a value in liters_per_kilometer.

        

        :param meters: The VolumePerLength value in liters_per_kilometer.
        :type liters_per_kilometer: float
        :return: A new instance of VolumePerLength.
        :rtype: VolumePerLength
        """
        return VolumePerLength(liters_per_kilometer, VolumePerLengthUnits.LiterPerKilometer)

    
    @staticmethod
    def from_liters_per_millimeter(liters_per_millimeter: float):
        """
        Create a new instance of VolumePerLength from a value in liters_per_millimeter.

        

        :param meters: The VolumePerLength value in liters_per_millimeter.
        :type liters_per_millimeter: float
        :return: A new instance of VolumePerLength.
        :rtype: VolumePerLength
        """
        return VolumePerLength(liters_per_millimeter, VolumePerLengthUnits.LiterPerMillimeter)

    
    @staticmethod
    def from_oil_barrels_per_foot(oil_barrels_per_foot: float):
        """
        Create a new instance of VolumePerLength from a value in oil_barrels_per_foot.

        

        :param meters: The VolumePerLength value in oil_barrels_per_foot.
        :type oil_barrels_per_foot: float
        :return: A new instance of VolumePerLength.
        :rtype: VolumePerLength
        """
        return VolumePerLength(oil_barrels_per_foot, VolumePerLengthUnits.OilBarrelPerFoot)

    
    @staticmethod
    def from_cubic_yards_per_foot(cubic_yards_per_foot: float):
        """
        Create a new instance of VolumePerLength from a value in cubic_yards_per_foot.

        

        :param meters: The VolumePerLength value in cubic_yards_per_foot.
        :type cubic_yards_per_foot: float
        :return: A new instance of VolumePerLength.
        :rtype: VolumePerLength
        """
        return VolumePerLength(cubic_yards_per_foot, VolumePerLengthUnits.CubicYardPerFoot)

    
    @staticmethod
    def from_cubic_yards_per_us_survey_foot(cubic_yards_per_us_survey_foot: float):
        """
        Create a new instance of VolumePerLength from a value in cubic_yards_per_us_survey_foot.

        

        :param meters: The VolumePerLength value in cubic_yards_per_us_survey_foot.
        :type cubic_yards_per_us_survey_foot: float
        :return: A new instance of VolumePerLength.
        :rtype: VolumePerLength
        """
        return VolumePerLength(cubic_yards_per_us_survey_foot, VolumePerLengthUnits.CubicYardPerUsSurveyFoot)

    
    @staticmethod
    def from_us_gallons_per_mile(us_gallons_per_mile: float):
        """
        Create a new instance of VolumePerLength from a value in us_gallons_per_mile.

        

        :param meters: The VolumePerLength value in us_gallons_per_mile.
        :type us_gallons_per_mile: float
        :return: A new instance of VolumePerLength.
        :rtype: VolumePerLength
        """
        return VolumePerLength(us_gallons_per_mile, VolumePerLengthUnits.UsGallonPerMile)

    
    @staticmethod
    def from_imperial_gallons_per_mile(imperial_gallons_per_mile: float):
        """
        Create a new instance of VolumePerLength from a value in imperial_gallons_per_mile.

        

        :param meters: The VolumePerLength value in imperial_gallons_per_mile.
        :type imperial_gallons_per_mile: float
        :return: A new instance of VolumePerLength.
        :rtype: VolumePerLength
        """
        return VolumePerLength(imperial_gallons_per_mile, VolumePerLengthUnits.ImperialGallonPerMile)

    
    @property
    def cubic_meters_per_meter(self) -> float:
        """
        
        """
        if self.__cubic_meters_per_meter != None:
            return self.__cubic_meters_per_meter
        self.__cubic_meters_per_meter = self.__convert_from_base(VolumePerLengthUnits.CubicMeterPerMeter)
        return self.__cubic_meters_per_meter

    
    @property
    def liters_per_meter(self) -> float:
        """
        
        """
        if self.__liters_per_meter != None:
            return self.__liters_per_meter
        self.__liters_per_meter = self.__convert_from_base(VolumePerLengthUnits.LiterPerMeter)
        return self.__liters_per_meter

    
    @property
    def liters_per_kilometer(self) -> float:
        """
        
        """
        if self.__liters_per_kilometer != None:
            return self.__liters_per_kilometer
        self.__liters_per_kilometer = self.__convert_from_base(VolumePerLengthUnits.LiterPerKilometer)
        return self.__liters_per_kilometer

    
    @property
    def liters_per_millimeter(self) -> float:
        """
        
        """
        if self.__liters_per_millimeter != None:
            return self.__liters_per_millimeter
        self.__liters_per_millimeter = self.__convert_from_base(VolumePerLengthUnits.LiterPerMillimeter)
        return self.__liters_per_millimeter

    
    @property
    def oil_barrels_per_foot(self) -> float:
        """
        
        """
        if self.__oil_barrels_per_foot != None:
            return self.__oil_barrels_per_foot
        self.__oil_barrels_per_foot = self.__convert_from_base(VolumePerLengthUnits.OilBarrelPerFoot)
        return self.__oil_barrels_per_foot

    
    @property
    def cubic_yards_per_foot(self) -> float:
        """
        
        """
        if self.__cubic_yards_per_foot != None:
            return self.__cubic_yards_per_foot
        self.__cubic_yards_per_foot = self.__convert_from_base(VolumePerLengthUnits.CubicYardPerFoot)
        return self.__cubic_yards_per_foot

    
    @property
    def cubic_yards_per_us_survey_foot(self) -> float:
        """
        
        """
        if self.__cubic_yards_per_us_survey_foot != None:
            return self.__cubic_yards_per_us_survey_foot
        self.__cubic_yards_per_us_survey_foot = self.__convert_from_base(VolumePerLengthUnits.CubicYardPerUsSurveyFoot)
        return self.__cubic_yards_per_us_survey_foot

    
    @property
    def us_gallons_per_mile(self) -> float:
        """
        
        """
        if self.__us_gallons_per_mile != None:
            return self.__us_gallons_per_mile
        self.__us_gallons_per_mile = self.__convert_from_base(VolumePerLengthUnits.UsGallonPerMile)
        return self.__us_gallons_per_mile

    
    @property
    def imperial_gallons_per_mile(self) -> float:
        """
        
        """
        if self.__imperial_gallons_per_mile != None:
            return self.__imperial_gallons_per_mile
        self.__imperial_gallons_per_mile = self.__convert_from_base(VolumePerLengthUnits.ImperialGallonPerMile)
        return self.__imperial_gallons_per_mile

    
    def to_string(self, unit: VolumePerLengthUnits = VolumePerLengthUnits.CubicMeterPerMeter) -> string:
        """
        Format the VolumePerLength to string.
        Note! the default format for VolumePerLength is CubicMeterPerMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == VolumePerLengthUnits.CubicMeterPerMeter:
            return f"""{self.cubic_meters_per_meter} m³/m"""
        
        if unit == VolumePerLengthUnits.LiterPerMeter:
            return f"""{self.liters_per_meter} l/m"""
        
        if unit == VolumePerLengthUnits.LiterPerKilometer:
            return f"""{self.liters_per_kilometer} l/km"""
        
        if unit == VolumePerLengthUnits.LiterPerMillimeter:
            return f"""{self.liters_per_millimeter} l/mm"""
        
        if unit == VolumePerLengthUnits.OilBarrelPerFoot:
            return f"""{self.oil_barrels_per_foot} bbl/ft"""
        
        if unit == VolumePerLengthUnits.CubicYardPerFoot:
            return f"""{self.cubic_yards_per_foot} yd³/ft"""
        
        if unit == VolumePerLengthUnits.CubicYardPerUsSurveyFoot:
            return f"""{self.cubic_yards_per_us_survey_foot} yd³/ftUS"""
        
        if unit == VolumePerLengthUnits.UsGallonPerMile:
            return f"""{self.us_gallons_per_mile} gal (U.S.)/mi"""
        
        if unit == VolumePerLengthUnits.ImperialGallonPerMile:
            return f"""{self.imperial_gallons_per_mile} gal (imp.)/mi"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: VolumePerLengthUnits = VolumePerLengthUnits.CubicMeterPerMeter) -> string:
        """
        Get VolumePerLength unit abbreviation.
        Note! the default abbreviation for VolumePerLength is CubicMeterPerMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == VolumePerLengthUnits.CubicMeterPerMeter:
            return """m³/m"""
        
        if unit_abbreviation == VolumePerLengthUnits.LiterPerMeter:
            return """l/m"""
        
        if unit_abbreviation == VolumePerLengthUnits.LiterPerKilometer:
            return """l/km"""
        
        if unit_abbreviation == VolumePerLengthUnits.LiterPerMillimeter:
            return """l/mm"""
        
        if unit_abbreviation == VolumePerLengthUnits.OilBarrelPerFoot:
            return """bbl/ft"""
        
        if unit_abbreviation == VolumePerLengthUnits.CubicYardPerFoot:
            return """yd³/ft"""
        
        if unit_abbreviation == VolumePerLengthUnits.CubicYardPerUsSurveyFoot:
            return """yd³/ftUS"""
        
        if unit_abbreviation == VolumePerLengthUnits.UsGallonPerMile:
            return """gal (U.S.)/mi"""
        
        if unit_abbreviation == VolumePerLengthUnits.ImperialGallonPerMile:
            return """gal (imp.)/mi"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for +: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return VolumePerLength(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for *: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return VolumePerLength(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for -: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return VolumePerLength(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for /: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return VolumePerLength(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for %: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return VolumePerLength(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for **: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return VolumePerLength(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for ==: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for <: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for >: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for <=: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, VolumePerLength):
            raise TypeError("unsupported operand type(s) for >=: 'VolumePerLength' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ForcePerLengthUnits(Enum):
        """
            ForcePerLengthUnits enumeration
        """
        
        NewtonPerMeter = 'newton_per_meter'
        """
            
        """
        
        NewtonPerCentimeter = 'newton_per_centimeter'
        """
            
        """
        
        NewtonPerMillimeter = 'newton_per_millimeter'
        """
            
        """
        
        KilogramForcePerMeter = 'kilogram_force_per_meter'
        """
            
        """
        
        KilogramForcePerCentimeter = 'kilogram_force_per_centimeter'
        """
            
        """
        
        KilogramForcePerMillimeter = 'kilogram_force_per_millimeter'
        """
            
        """
        
        TonneForcePerMeter = 'tonne_force_per_meter'
        """
            
        """
        
        TonneForcePerCentimeter = 'tonne_force_per_centimeter'
        """
            
        """
        
        TonneForcePerMillimeter = 'tonne_force_per_millimeter'
        """
            
        """
        
        PoundForcePerFoot = 'pound_force_per_foot'
        """
            
        """
        
        PoundForcePerInch = 'pound_force_per_inch'
        """
            
        """
        
        PoundForcePerYard = 'pound_force_per_yard'
        """
            
        """
        
        KilopoundForcePerFoot = 'kilopound_force_per_foot'
        """
            
        """
        
        KilopoundForcePerInch = 'kilopound_force_per_inch'
        """
            
        """
        
        NanonewtonPerMeter = 'nanonewton_per_meter'
        """
            
        """
        
        MicronewtonPerMeter = 'micronewton_per_meter'
        """
            
        """
        
        MillinewtonPerMeter = 'millinewton_per_meter'
        """
            
        """
        
        CentinewtonPerMeter = 'centinewton_per_meter'
        """
            
        """
        
        DecinewtonPerMeter = 'decinewton_per_meter'
        """
            
        """
        
        DecanewtonPerMeter = 'decanewton_per_meter'
        """
            
        """
        
        KilonewtonPerMeter = 'kilonewton_per_meter'
        """
            
        """
        
        MeganewtonPerMeter = 'meganewton_per_meter'
        """
            
        """
        
        NanonewtonPerCentimeter = 'nanonewton_per_centimeter'
        """
            
        """
        
        MicronewtonPerCentimeter = 'micronewton_per_centimeter'
        """
            
        """
        
        MillinewtonPerCentimeter = 'millinewton_per_centimeter'
        """
            
        """
        
        CentinewtonPerCentimeter = 'centinewton_per_centimeter'
        """
            
        """
        
        DecinewtonPerCentimeter = 'decinewton_per_centimeter'
        """
            
        """
        
        DecanewtonPerCentimeter = 'decanewton_per_centimeter'
        """
            
        """
        
        KilonewtonPerCentimeter = 'kilonewton_per_centimeter'
        """
            
        """
        
        MeganewtonPerCentimeter = 'meganewton_per_centimeter'
        """
            
        """
        
        NanonewtonPerMillimeter = 'nanonewton_per_millimeter'
        """
            
        """
        
        MicronewtonPerMillimeter = 'micronewton_per_millimeter'
        """
            
        """
        
        MillinewtonPerMillimeter = 'millinewton_per_millimeter'
        """
            
        """
        
        CentinewtonPerMillimeter = 'centinewton_per_millimeter'
        """
            
        """
        
        DecinewtonPerMillimeter = 'decinewton_per_millimeter'
        """
            
        """
        
        DecanewtonPerMillimeter = 'decanewton_per_millimeter'
        """
            
        """
        
        KilonewtonPerMillimeter = 'kilonewton_per_millimeter'
        """
            
        """
        
        MeganewtonPerMillimeter = 'meganewton_per_millimeter'
        """
            
        """
        

class ForcePerLength:
    """
    The magnitude of force per unit length.

    Args:
        value (float): The value.
        from_unit (ForcePerLengthUnits): The ForcePerLength unit to create from, The default unit is NewtonPerMeter
    """
    def __init__(self, value: float, from_unit: ForcePerLengthUnits = ForcePerLengthUnits.NewtonPerMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__newtons_per_meter = None
        
        self.__newtons_per_centimeter = None
        
        self.__newtons_per_millimeter = None
        
        self.__kilograms_force_per_meter = None
        
        self.__kilograms_force_per_centimeter = None
        
        self.__kilograms_force_per_millimeter = None
        
        self.__tonnes_force_per_meter = None
        
        self.__tonnes_force_per_centimeter = None
        
        self.__tonnes_force_per_millimeter = None
        
        self.__pounds_force_per_foot = None
        
        self.__pounds_force_per_inch = None
        
        self.__pounds_force_per_yard = None
        
        self.__kilopounds_force_per_foot = None
        
        self.__kilopounds_force_per_inch = None
        
        self.__nanonewtons_per_meter = None
        
        self.__micronewtons_per_meter = None
        
        self.__millinewtons_per_meter = None
        
        self.__centinewtons_per_meter = None
        
        self.__decinewtons_per_meter = None
        
        self.__decanewtons_per_meter = None
        
        self.__kilonewtons_per_meter = None
        
        self.__meganewtons_per_meter = None
        
        self.__nanonewtons_per_centimeter = None
        
        self.__micronewtons_per_centimeter = None
        
        self.__millinewtons_per_centimeter = None
        
        self.__centinewtons_per_centimeter = None
        
        self.__decinewtons_per_centimeter = None
        
        self.__decanewtons_per_centimeter = None
        
        self.__kilonewtons_per_centimeter = None
        
        self.__meganewtons_per_centimeter = None
        
        self.__nanonewtons_per_millimeter = None
        
        self.__micronewtons_per_millimeter = None
        
        self.__millinewtons_per_millimeter = None
        
        self.__centinewtons_per_millimeter = None
        
        self.__decinewtons_per_millimeter = None
        
        self.__decanewtons_per_millimeter = None
        
        self.__kilonewtons_per_millimeter = None
        
        self.__meganewtons_per_millimeter = None
        

    def __convert_from_base(self, from_unit: ForcePerLengthUnits) -> float:
        value = self.__value
        
        if from_unit == ForcePerLengthUnits.NewtonPerMeter:
            return (value)
        
        if from_unit == ForcePerLengthUnits.NewtonPerCentimeter:
            return (value / 1e2)
        
        if from_unit == ForcePerLengthUnits.NewtonPerMillimeter:
            return (value / 1e3)
        
        if from_unit == ForcePerLengthUnits.KilogramForcePerMeter:
            return (value / 9.80665002864)
        
        if from_unit == ForcePerLengthUnits.KilogramForcePerCentimeter:
            return (value / 980.665002864)
        
        if from_unit == ForcePerLengthUnits.KilogramForcePerMillimeter:
            return (value / 9.80665002864e3)
        
        if from_unit == ForcePerLengthUnits.TonneForcePerMeter:
            return (value / 9.80665002864e3)
        
        if from_unit == ForcePerLengthUnits.TonneForcePerCentimeter:
            return (value / 9.80665002864e5)
        
        if from_unit == ForcePerLengthUnits.TonneForcePerMillimeter:
            return (value / 9.80665002864e6)
        
        if from_unit == ForcePerLengthUnits.PoundForcePerFoot:
            return (value / 14.59390292)
        
        if from_unit == ForcePerLengthUnits.PoundForcePerInch:
            return (value / 1.75126835e2)
        
        if from_unit == ForcePerLengthUnits.PoundForcePerYard:
            return (value / 4.864634307)
        
        if from_unit == ForcePerLengthUnits.KilopoundForcePerFoot:
            return (value / 14593.90292)
        
        if from_unit == ForcePerLengthUnits.KilopoundForcePerInch:
            return (value / 1.75126835e5)
        
        if from_unit == ForcePerLengthUnits.NanonewtonPerMeter:
            return ((value) / 1e-09)
        
        if from_unit == ForcePerLengthUnits.MicronewtonPerMeter:
            return ((value) / 1e-06)
        
        if from_unit == ForcePerLengthUnits.MillinewtonPerMeter:
            return ((value) / 0.001)
        
        if from_unit == ForcePerLengthUnits.CentinewtonPerMeter:
            return ((value) / 0.01)
        
        if from_unit == ForcePerLengthUnits.DecinewtonPerMeter:
            return ((value) / 0.1)
        
        if from_unit == ForcePerLengthUnits.DecanewtonPerMeter:
            return ((value) / 10.0)
        
        if from_unit == ForcePerLengthUnits.KilonewtonPerMeter:
            return ((value) / 1000.0)
        
        if from_unit == ForcePerLengthUnits.MeganewtonPerMeter:
            return ((value) / 1000000.0)
        
        if from_unit == ForcePerLengthUnits.NanonewtonPerCentimeter:
            return ((value / 1e2) / 1e-09)
        
        if from_unit == ForcePerLengthUnits.MicronewtonPerCentimeter:
            return ((value / 1e2) / 1e-06)
        
        if from_unit == ForcePerLengthUnits.MillinewtonPerCentimeter:
            return ((value / 1e2) / 0.001)
        
        if from_unit == ForcePerLengthUnits.CentinewtonPerCentimeter:
            return ((value / 1e2) / 0.01)
        
        if from_unit == ForcePerLengthUnits.DecinewtonPerCentimeter:
            return ((value / 1e2) / 0.1)
        
        if from_unit == ForcePerLengthUnits.DecanewtonPerCentimeter:
            return ((value / 1e2) / 10.0)
        
        if from_unit == ForcePerLengthUnits.KilonewtonPerCentimeter:
            return ((value / 1e2) / 1000.0)
        
        if from_unit == ForcePerLengthUnits.MeganewtonPerCentimeter:
            return ((value / 1e2) / 1000000.0)
        
        if from_unit == ForcePerLengthUnits.NanonewtonPerMillimeter:
            return ((value / 1e3) / 1e-09)
        
        if from_unit == ForcePerLengthUnits.MicronewtonPerMillimeter:
            return ((value / 1e3) / 1e-06)
        
        if from_unit == ForcePerLengthUnits.MillinewtonPerMillimeter:
            return ((value / 1e3) / 0.001)
        
        if from_unit == ForcePerLengthUnits.CentinewtonPerMillimeter:
            return ((value / 1e3) / 0.01)
        
        if from_unit == ForcePerLengthUnits.DecinewtonPerMillimeter:
            return ((value / 1e3) / 0.1)
        
        if from_unit == ForcePerLengthUnits.DecanewtonPerMillimeter:
            return ((value / 1e3) / 10.0)
        
        if from_unit == ForcePerLengthUnits.KilonewtonPerMillimeter:
            return ((value / 1e3) / 1000.0)
        
        if from_unit == ForcePerLengthUnits.MeganewtonPerMillimeter:
            return ((value / 1e3) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ForcePerLengthUnits) -> float:
        
        if to_unit == ForcePerLengthUnits.NewtonPerMeter:
            return (value)
        
        if to_unit == ForcePerLengthUnits.NewtonPerCentimeter:
            return (value * 1e2)
        
        if to_unit == ForcePerLengthUnits.NewtonPerMillimeter:
            return (value * 1e3)
        
        if to_unit == ForcePerLengthUnits.KilogramForcePerMeter:
            return (value * 9.80665002864)
        
        if to_unit == ForcePerLengthUnits.KilogramForcePerCentimeter:
            return (value * 980.665002864)
        
        if to_unit == ForcePerLengthUnits.KilogramForcePerMillimeter:
            return (value * 9.80665002864e3)
        
        if to_unit == ForcePerLengthUnits.TonneForcePerMeter:
            return (value * 9.80665002864e3)
        
        if to_unit == ForcePerLengthUnits.TonneForcePerCentimeter:
            return (value * 9.80665002864e5)
        
        if to_unit == ForcePerLengthUnits.TonneForcePerMillimeter:
            return (value * 9.80665002864e6)
        
        if to_unit == ForcePerLengthUnits.PoundForcePerFoot:
            return (value * 14.59390292)
        
        if to_unit == ForcePerLengthUnits.PoundForcePerInch:
            return (value * 1.75126835e2)
        
        if to_unit == ForcePerLengthUnits.PoundForcePerYard:
            return (value * 4.864634307)
        
        if to_unit == ForcePerLengthUnits.KilopoundForcePerFoot:
            return (value * 14593.90292)
        
        if to_unit == ForcePerLengthUnits.KilopoundForcePerInch:
            return (value * 1.75126835e5)
        
        if to_unit == ForcePerLengthUnits.NanonewtonPerMeter:
            return ((value) * 1e-09)
        
        if to_unit == ForcePerLengthUnits.MicronewtonPerMeter:
            return ((value) * 1e-06)
        
        if to_unit == ForcePerLengthUnits.MillinewtonPerMeter:
            return ((value) * 0.001)
        
        if to_unit == ForcePerLengthUnits.CentinewtonPerMeter:
            return ((value) * 0.01)
        
        if to_unit == ForcePerLengthUnits.DecinewtonPerMeter:
            return ((value) * 0.1)
        
        if to_unit == ForcePerLengthUnits.DecanewtonPerMeter:
            return ((value) * 10.0)
        
        if to_unit == ForcePerLengthUnits.KilonewtonPerMeter:
            return ((value) * 1000.0)
        
        if to_unit == ForcePerLengthUnits.MeganewtonPerMeter:
            return ((value) * 1000000.0)
        
        if to_unit == ForcePerLengthUnits.NanonewtonPerCentimeter:
            return ((value * 1e2) * 1e-09)
        
        if to_unit == ForcePerLengthUnits.MicronewtonPerCentimeter:
            return ((value * 1e2) * 1e-06)
        
        if to_unit == ForcePerLengthUnits.MillinewtonPerCentimeter:
            return ((value * 1e2) * 0.001)
        
        if to_unit == ForcePerLengthUnits.CentinewtonPerCentimeter:
            return ((value * 1e2) * 0.01)
        
        if to_unit == ForcePerLengthUnits.DecinewtonPerCentimeter:
            return ((value * 1e2) * 0.1)
        
        if to_unit == ForcePerLengthUnits.DecanewtonPerCentimeter:
            return ((value * 1e2) * 10.0)
        
        if to_unit == ForcePerLengthUnits.KilonewtonPerCentimeter:
            return ((value * 1e2) * 1000.0)
        
        if to_unit == ForcePerLengthUnits.MeganewtonPerCentimeter:
            return ((value * 1e2) * 1000000.0)
        
        if to_unit == ForcePerLengthUnits.NanonewtonPerMillimeter:
            return ((value * 1e3) * 1e-09)
        
        if to_unit == ForcePerLengthUnits.MicronewtonPerMillimeter:
            return ((value * 1e3) * 1e-06)
        
        if to_unit == ForcePerLengthUnits.MillinewtonPerMillimeter:
            return ((value * 1e3) * 0.001)
        
        if to_unit == ForcePerLengthUnits.CentinewtonPerMillimeter:
            return ((value * 1e3) * 0.01)
        
        if to_unit == ForcePerLengthUnits.DecinewtonPerMillimeter:
            return ((value * 1e3) * 0.1)
        
        if to_unit == ForcePerLengthUnits.DecanewtonPerMillimeter:
            return ((value * 1e3) * 10.0)
        
        if to_unit == ForcePerLengthUnits.KilonewtonPerMillimeter:
            return ((value * 1e3) * 1000.0)
        
        if to_unit == ForcePerLengthUnits.MeganewtonPerMillimeter:
            return ((value * 1e3) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_newtons_per_meter(newtons_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in newtons_per_meter.

        

        :param meters: The ForcePerLength value in newtons_per_meter.
        :type newtons_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(newtons_per_meter, ForcePerLengthUnits.NewtonPerMeter)

    
    @staticmethod
    def from_newtons_per_centimeter(newtons_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in newtons_per_centimeter.

        

        :param meters: The ForcePerLength value in newtons_per_centimeter.
        :type newtons_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(newtons_per_centimeter, ForcePerLengthUnits.NewtonPerCentimeter)

    
    @staticmethod
    def from_newtons_per_millimeter(newtons_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in newtons_per_millimeter.

        

        :param meters: The ForcePerLength value in newtons_per_millimeter.
        :type newtons_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(newtons_per_millimeter, ForcePerLengthUnits.NewtonPerMillimeter)

    
    @staticmethod
    def from_kilograms_force_per_meter(kilograms_force_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in kilograms_force_per_meter.

        

        :param meters: The ForcePerLength value in kilograms_force_per_meter.
        :type kilograms_force_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(kilograms_force_per_meter, ForcePerLengthUnits.KilogramForcePerMeter)

    
    @staticmethod
    def from_kilograms_force_per_centimeter(kilograms_force_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in kilograms_force_per_centimeter.

        

        :param meters: The ForcePerLength value in kilograms_force_per_centimeter.
        :type kilograms_force_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(kilograms_force_per_centimeter, ForcePerLengthUnits.KilogramForcePerCentimeter)

    
    @staticmethod
    def from_kilograms_force_per_millimeter(kilograms_force_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in kilograms_force_per_millimeter.

        

        :param meters: The ForcePerLength value in kilograms_force_per_millimeter.
        :type kilograms_force_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(kilograms_force_per_millimeter, ForcePerLengthUnits.KilogramForcePerMillimeter)

    
    @staticmethod
    def from_tonnes_force_per_meter(tonnes_force_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in tonnes_force_per_meter.

        

        :param meters: The ForcePerLength value in tonnes_force_per_meter.
        :type tonnes_force_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(tonnes_force_per_meter, ForcePerLengthUnits.TonneForcePerMeter)

    
    @staticmethod
    def from_tonnes_force_per_centimeter(tonnes_force_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in tonnes_force_per_centimeter.

        

        :param meters: The ForcePerLength value in tonnes_force_per_centimeter.
        :type tonnes_force_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(tonnes_force_per_centimeter, ForcePerLengthUnits.TonneForcePerCentimeter)

    
    @staticmethod
    def from_tonnes_force_per_millimeter(tonnes_force_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in tonnes_force_per_millimeter.

        

        :param meters: The ForcePerLength value in tonnes_force_per_millimeter.
        :type tonnes_force_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(tonnes_force_per_millimeter, ForcePerLengthUnits.TonneForcePerMillimeter)

    
    @staticmethod
    def from_pounds_force_per_foot(pounds_force_per_foot: float):
        """
        Create a new instance of ForcePerLength from a value in pounds_force_per_foot.

        

        :param meters: The ForcePerLength value in pounds_force_per_foot.
        :type pounds_force_per_foot: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(pounds_force_per_foot, ForcePerLengthUnits.PoundForcePerFoot)

    
    @staticmethod
    def from_pounds_force_per_inch(pounds_force_per_inch: float):
        """
        Create a new instance of ForcePerLength from a value in pounds_force_per_inch.

        

        :param meters: The ForcePerLength value in pounds_force_per_inch.
        :type pounds_force_per_inch: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(pounds_force_per_inch, ForcePerLengthUnits.PoundForcePerInch)

    
    @staticmethod
    def from_pounds_force_per_yard(pounds_force_per_yard: float):
        """
        Create a new instance of ForcePerLength from a value in pounds_force_per_yard.

        

        :param meters: The ForcePerLength value in pounds_force_per_yard.
        :type pounds_force_per_yard: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(pounds_force_per_yard, ForcePerLengthUnits.PoundForcePerYard)

    
    @staticmethod
    def from_kilopounds_force_per_foot(kilopounds_force_per_foot: float):
        """
        Create a new instance of ForcePerLength from a value in kilopounds_force_per_foot.

        

        :param meters: The ForcePerLength value in kilopounds_force_per_foot.
        :type kilopounds_force_per_foot: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(kilopounds_force_per_foot, ForcePerLengthUnits.KilopoundForcePerFoot)

    
    @staticmethod
    def from_kilopounds_force_per_inch(kilopounds_force_per_inch: float):
        """
        Create a new instance of ForcePerLength from a value in kilopounds_force_per_inch.

        

        :param meters: The ForcePerLength value in kilopounds_force_per_inch.
        :type kilopounds_force_per_inch: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(kilopounds_force_per_inch, ForcePerLengthUnits.KilopoundForcePerInch)

    
    @staticmethod
    def from_nanonewtons_per_meter(nanonewtons_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in nanonewtons_per_meter.

        

        :param meters: The ForcePerLength value in nanonewtons_per_meter.
        :type nanonewtons_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(nanonewtons_per_meter, ForcePerLengthUnits.NanonewtonPerMeter)

    
    @staticmethod
    def from_micronewtons_per_meter(micronewtons_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in micronewtons_per_meter.

        

        :param meters: The ForcePerLength value in micronewtons_per_meter.
        :type micronewtons_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(micronewtons_per_meter, ForcePerLengthUnits.MicronewtonPerMeter)

    
    @staticmethod
    def from_millinewtons_per_meter(millinewtons_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in millinewtons_per_meter.

        

        :param meters: The ForcePerLength value in millinewtons_per_meter.
        :type millinewtons_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(millinewtons_per_meter, ForcePerLengthUnits.MillinewtonPerMeter)

    
    @staticmethod
    def from_centinewtons_per_meter(centinewtons_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in centinewtons_per_meter.

        

        :param meters: The ForcePerLength value in centinewtons_per_meter.
        :type centinewtons_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(centinewtons_per_meter, ForcePerLengthUnits.CentinewtonPerMeter)

    
    @staticmethod
    def from_decinewtons_per_meter(decinewtons_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in decinewtons_per_meter.

        

        :param meters: The ForcePerLength value in decinewtons_per_meter.
        :type decinewtons_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(decinewtons_per_meter, ForcePerLengthUnits.DecinewtonPerMeter)

    
    @staticmethod
    def from_decanewtons_per_meter(decanewtons_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in decanewtons_per_meter.

        

        :param meters: The ForcePerLength value in decanewtons_per_meter.
        :type decanewtons_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(decanewtons_per_meter, ForcePerLengthUnits.DecanewtonPerMeter)

    
    @staticmethod
    def from_kilonewtons_per_meter(kilonewtons_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in kilonewtons_per_meter.

        

        :param meters: The ForcePerLength value in kilonewtons_per_meter.
        :type kilonewtons_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(kilonewtons_per_meter, ForcePerLengthUnits.KilonewtonPerMeter)

    
    @staticmethod
    def from_meganewtons_per_meter(meganewtons_per_meter: float):
        """
        Create a new instance of ForcePerLength from a value in meganewtons_per_meter.

        

        :param meters: The ForcePerLength value in meganewtons_per_meter.
        :type meganewtons_per_meter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(meganewtons_per_meter, ForcePerLengthUnits.MeganewtonPerMeter)

    
    @staticmethod
    def from_nanonewtons_per_centimeter(nanonewtons_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in nanonewtons_per_centimeter.

        

        :param meters: The ForcePerLength value in nanonewtons_per_centimeter.
        :type nanonewtons_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(nanonewtons_per_centimeter, ForcePerLengthUnits.NanonewtonPerCentimeter)

    
    @staticmethod
    def from_micronewtons_per_centimeter(micronewtons_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in micronewtons_per_centimeter.

        

        :param meters: The ForcePerLength value in micronewtons_per_centimeter.
        :type micronewtons_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(micronewtons_per_centimeter, ForcePerLengthUnits.MicronewtonPerCentimeter)

    
    @staticmethod
    def from_millinewtons_per_centimeter(millinewtons_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in millinewtons_per_centimeter.

        

        :param meters: The ForcePerLength value in millinewtons_per_centimeter.
        :type millinewtons_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(millinewtons_per_centimeter, ForcePerLengthUnits.MillinewtonPerCentimeter)

    
    @staticmethod
    def from_centinewtons_per_centimeter(centinewtons_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in centinewtons_per_centimeter.

        

        :param meters: The ForcePerLength value in centinewtons_per_centimeter.
        :type centinewtons_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(centinewtons_per_centimeter, ForcePerLengthUnits.CentinewtonPerCentimeter)

    
    @staticmethod
    def from_decinewtons_per_centimeter(decinewtons_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in decinewtons_per_centimeter.

        

        :param meters: The ForcePerLength value in decinewtons_per_centimeter.
        :type decinewtons_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(decinewtons_per_centimeter, ForcePerLengthUnits.DecinewtonPerCentimeter)

    
    @staticmethod
    def from_decanewtons_per_centimeter(decanewtons_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in decanewtons_per_centimeter.

        

        :param meters: The ForcePerLength value in decanewtons_per_centimeter.
        :type decanewtons_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(decanewtons_per_centimeter, ForcePerLengthUnits.DecanewtonPerCentimeter)

    
    @staticmethod
    def from_kilonewtons_per_centimeter(kilonewtons_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in kilonewtons_per_centimeter.

        

        :param meters: The ForcePerLength value in kilonewtons_per_centimeter.
        :type kilonewtons_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(kilonewtons_per_centimeter, ForcePerLengthUnits.KilonewtonPerCentimeter)

    
    @staticmethod
    def from_meganewtons_per_centimeter(meganewtons_per_centimeter: float):
        """
        Create a new instance of ForcePerLength from a value in meganewtons_per_centimeter.

        

        :param meters: The ForcePerLength value in meganewtons_per_centimeter.
        :type meganewtons_per_centimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(meganewtons_per_centimeter, ForcePerLengthUnits.MeganewtonPerCentimeter)

    
    @staticmethod
    def from_nanonewtons_per_millimeter(nanonewtons_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in nanonewtons_per_millimeter.

        

        :param meters: The ForcePerLength value in nanonewtons_per_millimeter.
        :type nanonewtons_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(nanonewtons_per_millimeter, ForcePerLengthUnits.NanonewtonPerMillimeter)

    
    @staticmethod
    def from_micronewtons_per_millimeter(micronewtons_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in micronewtons_per_millimeter.

        

        :param meters: The ForcePerLength value in micronewtons_per_millimeter.
        :type micronewtons_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(micronewtons_per_millimeter, ForcePerLengthUnits.MicronewtonPerMillimeter)

    
    @staticmethod
    def from_millinewtons_per_millimeter(millinewtons_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in millinewtons_per_millimeter.

        

        :param meters: The ForcePerLength value in millinewtons_per_millimeter.
        :type millinewtons_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(millinewtons_per_millimeter, ForcePerLengthUnits.MillinewtonPerMillimeter)

    
    @staticmethod
    def from_centinewtons_per_millimeter(centinewtons_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in centinewtons_per_millimeter.

        

        :param meters: The ForcePerLength value in centinewtons_per_millimeter.
        :type centinewtons_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(centinewtons_per_millimeter, ForcePerLengthUnits.CentinewtonPerMillimeter)

    
    @staticmethod
    def from_decinewtons_per_millimeter(decinewtons_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in decinewtons_per_millimeter.

        

        :param meters: The ForcePerLength value in decinewtons_per_millimeter.
        :type decinewtons_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(decinewtons_per_millimeter, ForcePerLengthUnits.DecinewtonPerMillimeter)

    
    @staticmethod
    def from_decanewtons_per_millimeter(decanewtons_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in decanewtons_per_millimeter.

        

        :param meters: The ForcePerLength value in decanewtons_per_millimeter.
        :type decanewtons_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(decanewtons_per_millimeter, ForcePerLengthUnits.DecanewtonPerMillimeter)

    
    @staticmethod
    def from_kilonewtons_per_millimeter(kilonewtons_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in kilonewtons_per_millimeter.

        

        :param meters: The ForcePerLength value in kilonewtons_per_millimeter.
        :type kilonewtons_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(kilonewtons_per_millimeter, ForcePerLengthUnits.KilonewtonPerMillimeter)

    
    @staticmethod
    def from_meganewtons_per_millimeter(meganewtons_per_millimeter: float):
        """
        Create a new instance of ForcePerLength from a value in meganewtons_per_millimeter.

        

        :param meters: The ForcePerLength value in meganewtons_per_millimeter.
        :type meganewtons_per_millimeter: float
        :return: A new instance of ForcePerLength.
        :rtype: ForcePerLength
        """
        return ForcePerLength(meganewtons_per_millimeter, ForcePerLengthUnits.MeganewtonPerMillimeter)

    
    @property
    def newtons_per_meter(self) -> float:
        """
        
        """
        if self.__newtons_per_meter != None:
            return self.__newtons_per_meter
        self.__newtons_per_meter = self.__convert_from_base(ForcePerLengthUnits.NewtonPerMeter)
        return self.__newtons_per_meter

    
    @property
    def newtons_per_centimeter(self) -> float:
        """
        
        """
        if self.__newtons_per_centimeter != None:
            return self.__newtons_per_centimeter
        self.__newtons_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.NewtonPerCentimeter)
        return self.__newtons_per_centimeter

    
    @property
    def newtons_per_millimeter(self) -> float:
        """
        
        """
        if self.__newtons_per_millimeter != None:
            return self.__newtons_per_millimeter
        self.__newtons_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.NewtonPerMillimeter)
        return self.__newtons_per_millimeter

    
    @property
    def kilograms_force_per_meter(self) -> float:
        """
        
        """
        if self.__kilograms_force_per_meter != None:
            return self.__kilograms_force_per_meter
        self.__kilograms_force_per_meter = self.__convert_from_base(ForcePerLengthUnits.KilogramForcePerMeter)
        return self.__kilograms_force_per_meter

    
    @property
    def kilograms_force_per_centimeter(self) -> float:
        """
        
        """
        if self.__kilograms_force_per_centimeter != None:
            return self.__kilograms_force_per_centimeter
        self.__kilograms_force_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.KilogramForcePerCentimeter)
        return self.__kilograms_force_per_centimeter

    
    @property
    def kilograms_force_per_millimeter(self) -> float:
        """
        
        """
        if self.__kilograms_force_per_millimeter != None:
            return self.__kilograms_force_per_millimeter
        self.__kilograms_force_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.KilogramForcePerMillimeter)
        return self.__kilograms_force_per_millimeter

    
    @property
    def tonnes_force_per_meter(self) -> float:
        """
        
        """
        if self.__tonnes_force_per_meter != None:
            return self.__tonnes_force_per_meter
        self.__tonnes_force_per_meter = self.__convert_from_base(ForcePerLengthUnits.TonneForcePerMeter)
        return self.__tonnes_force_per_meter

    
    @property
    def tonnes_force_per_centimeter(self) -> float:
        """
        
        """
        if self.__tonnes_force_per_centimeter != None:
            return self.__tonnes_force_per_centimeter
        self.__tonnes_force_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.TonneForcePerCentimeter)
        return self.__tonnes_force_per_centimeter

    
    @property
    def tonnes_force_per_millimeter(self) -> float:
        """
        
        """
        if self.__tonnes_force_per_millimeter != None:
            return self.__tonnes_force_per_millimeter
        self.__tonnes_force_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.TonneForcePerMillimeter)
        return self.__tonnes_force_per_millimeter

    
    @property
    def pounds_force_per_foot(self) -> float:
        """
        
        """
        if self.__pounds_force_per_foot != None:
            return self.__pounds_force_per_foot
        self.__pounds_force_per_foot = self.__convert_from_base(ForcePerLengthUnits.PoundForcePerFoot)
        return self.__pounds_force_per_foot

    
    @property
    def pounds_force_per_inch(self) -> float:
        """
        
        """
        if self.__pounds_force_per_inch != None:
            return self.__pounds_force_per_inch
        self.__pounds_force_per_inch = self.__convert_from_base(ForcePerLengthUnits.PoundForcePerInch)
        return self.__pounds_force_per_inch

    
    @property
    def pounds_force_per_yard(self) -> float:
        """
        
        """
        if self.__pounds_force_per_yard != None:
            return self.__pounds_force_per_yard
        self.__pounds_force_per_yard = self.__convert_from_base(ForcePerLengthUnits.PoundForcePerYard)
        return self.__pounds_force_per_yard

    
    @property
    def kilopounds_force_per_foot(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_foot != None:
            return self.__kilopounds_force_per_foot
        self.__kilopounds_force_per_foot = self.__convert_from_base(ForcePerLengthUnits.KilopoundForcePerFoot)
        return self.__kilopounds_force_per_foot

    
    @property
    def kilopounds_force_per_inch(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_inch != None:
            return self.__kilopounds_force_per_inch
        self.__kilopounds_force_per_inch = self.__convert_from_base(ForcePerLengthUnits.KilopoundForcePerInch)
        return self.__kilopounds_force_per_inch

    
    @property
    def nanonewtons_per_meter(self) -> float:
        """
        
        """
        if self.__nanonewtons_per_meter != None:
            return self.__nanonewtons_per_meter
        self.__nanonewtons_per_meter = self.__convert_from_base(ForcePerLengthUnits.NanonewtonPerMeter)
        return self.__nanonewtons_per_meter

    
    @property
    def micronewtons_per_meter(self) -> float:
        """
        
        """
        if self.__micronewtons_per_meter != None:
            return self.__micronewtons_per_meter
        self.__micronewtons_per_meter = self.__convert_from_base(ForcePerLengthUnits.MicronewtonPerMeter)
        return self.__micronewtons_per_meter

    
    @property
    def millinewtons_per_meter(self) -> float:
        """
        
        """
        if self.__millinewtons_per_meter != None:
            return self.__millinewtons_per_meter
        self.__millinewtons_per_meter = self.__convert_from_base(ForcePerLengthUnits.MillinewtonPerMeter)
        return self.__millinewtons_per_meter

    
    @property
    def centinewtons_per_meter(self) -> float:
        """
        
        """
        if self.__centinewtons_per_meter != None:
            return self.__centinewtons_per_meter
        self.__centinewtons_per_meter = self.__convert_from_base(ForcePerLengthUnits.CentinewtonPerMeter)
        return self.__centinewtons_per_meter

    
    @property
    def decinewtons_per_meter(self) -> float:
        """
        
        """
        if self.__decinewtons_per_meter != None:
            return self.__decinewtons_per_meter
        self.__decinewtons_per_meter = self.__convert_from_base(ForcePerLengthUnits.DecinewtonPerMeter)
        return self.__decinewtons_per_meter

    
    @property
    def decanewtons_per_meter(self) -> float:
        """
        
        """
        if self.__decanewtons_per_meter != None:
            return self.__decanewtons_per_meter
        self.__decanewtons_per_meter = self.__convert_from_base(ForcePerLengthUnits.DecanewtonPerMeter)
        return self.__decanewtons_per_meter

    
    @property
    def kilonewtons_per_meter(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_meter != None:
            return self.__kilonewtons_per_meter
        self.__kilonewtons_per_meter = self.__convert_from_base(ForcePerLengthUnits.KilonewtonPerMeter)
        return self.__kilonewtons_per_meter

    
    @property
    def meganewtons_per_meter(self) -> float:
        """
        
        """
        if self.__meganewtons_per_meter != None:
            return self.__meganewtons_per_meter
        self.__meganewtons_per_meter = self.__convert_from_base(ForcePerLengthUnits.MeganewtonPerMeter)
        return self.__meganewtons_per_meter

    
    @property
    def nanonewtons_per_centimeter(self) -> float:
        """
        
        """
        if self.__nanonewtons_per_centimeter != None:
            return self.__nanonewtons_per_centimeter
        self.__nanonewtons_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.NanonewtonPerCentimeter)
        return self.__nanonewtons_per_centimeter

    
    @property
    def micronewtons_per_centimeter(self) -> float:
        """
        
        """
        if self.__micronewtons_per_centimeter != None:
            return self.__micronewtons_per_centimeter
        self.__micronewtons_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.MicronewtonPerCentimeter)
        return self.__micronewtons_per_centimeter

    
    @property
    def millinewtons_per_centimeter(self) -> float:
        """
        
        """
        if self.__millinewtons_per_centimeter != None:
            return self.__millinewtons_per_centimeter
        self.__millinewtons_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.MillinewtonPerCentimeter)
        return self.__millinewtons_per_centimeter

    
    @property
    def centinewtons_per_centimeter(self) -> float:
        """
        
        """
        if self.__centinewtons_per_centimeter != None:
            return self.__centinewtons_per_centimeter
        self.__centinewtons_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.CentinewtonPerCentimeter)
        return self.__centinewtons_per_centimeter

    
    @property
    def decinewtons_per_centimeter(self) -> float:
        """
        
        """
        if self.__decinewtons_per_centimeter != None:
            return self.__decinewtons_per_centimeter
        self.__decinewtons_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.DecinewtonPerCentimeter)
        return self.__decinewtons_per_centimeter

    
    @property
    def decanewtons_per_centimeter(self) -> float:
        """
        
        """
        if self.__decanewtons_per_centimeter != None:
            return self.__decanewtons_per_centimeter
        self.__decanewtons_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.DecanewtonPerCentimeter)
        return self.__decanewtons_per_centimeter

    
    @property
    def kilonewtons_per_centimeter(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_centimeter != None:
            return self.__kilonewtons_per_centimeter
        self.__kilonewtons_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.KilonewtonPerCentimeter)
        return self.__kilonewtons_per_centimeter

    
    @property
    def meganewtons_per_centimeter(self) -> float:
        """
        
        """
        if self.__meganewtons_per_centimeter != None:
            return self.__meganewtons_per_centimeter
        self.__meganewtons_per_centimeter = self.__convert_from_base(ForcePerLengthUnits.MeganewtonPerCentimeter)
        return self.__meganewtons_per_centimeter

    
    @property
    def nanonewtons_per_millimeter(self) -> float:
        """
        
        """
        if self.__nanonewtons_per_millimeter != None:
            return self.__nanonewtons_per_millimeter
        self.__nanonewtons_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.NanonewtonPerMillimeter)
        return self.__nanonewtons_per_millimeter

    
    @property
    def micronewtons_per_millimeter(self) -> float:
        """
        
        """
        if self.__micronewtons_per_millimeter != None:
            return self.__micronewtons_per_millimeter
        self.__micronewtons_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.MicronewtonPerMillimeter)
        return self.__micronewtons_per_millimeter

    
    @property
    def millinewtons_per_millimeter(self) -> float:
        """
        
        """
        if self.__millinewtons_per_millimeter != None:
            return self.__millinewtons_per_millimeter
        self.__millinewtons_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.MillinewtonPerMillimeter)
        return self.__millinewtons_per_millimeter

    
    @property
    def centinewtons_per_millimeter(self) -> float:
        """
        
        """
        if self.__centinewtons_per_millimeter != None:
            return self.__centinewtons_per_millimeter
        self.__centinewtons_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.CentinewtonPerMillimeter)
        return self.__centinewtons_per_millimeter

    
    @property
    def decinewtons_per_millimeter(self) -> float:
        """
        
        """
        if self.__decinewtons_per_millimeter != None:
            return self.__decinewtons_per_millimeter
        self.__decinewtons_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.DecinewtonPerMillimeter)
        return self.__decinewtons_per_millimeter

    
    @property
    def decanewtons_per_millimeter(self) -> float:
        """
        
        """
        if self.__decanewtons_per_millimeter != None:
            return self.__decanewtons_per_millimeter
        self.__decanewtons_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.DecanewtonPerMillimeter)
        return self.__decanewtons_per_millimeter

    
    @property
    def kilonewtons_per_millimeter(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_millimeter != None:
            return self.__kilonewtons_per_millimeter
        self.__kilonewtons_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.KilonewtonPerMillimeter)
        return self.__kilonewtons_per_millimeter

    
    @property
    def meganewtons_per_millimeter(self) -> float:
        """
        
        """
        if self.__meganewtons_per_millimeter != None:
            return self.__meganewtons_per_millimeter
        self.__meganewtons_per_millimeter = self.__convert_from_base(ForcePerLengthUnits.MeganewtonPerMillimeter)
        return self.__meganewtons_per_millimeter

    
    def to_string(self, unit: ForcePerLengthUnits = ForcePerLengthUnits.NewtonPerMeter) -> string:
        """
        Format the ForcePerLength to string.
        Note! the default format for ForcePerLength is NewtonPerMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ForcePerLengthUnits.NewtonPerMeter:
            return f"""{self.newtons_per_meter} N/m"""
        
        if unit == ForcePerLengthUnits.NewtonPerCentimeter:
            return f"""{self.newtons_per_centimeter} N/cm"""
        
        if unit == ForcePerLengthUnits.NewtonPerMillimeter:
            return f"""{self.newtons_per_millimeter} N/mm"""
        
        if unit == ForcePerLengthUnits.KilogramForcePerMeter:
            return f"""{self.kilograms_force_per_meter} kgf/m"""
        
        if unit == ForcePerLengthUnits.KilogramForcePerCentimeter:
            return f"""{self.kilograms_force_per_centimeter} kgf/cm"""
        
        if unit == ForcePerLengthUnits.KilogramForcePerMillimeter:
            return f"""{self.kilograms_force_per_millimeter} kgf/mm"""
        
        if unit == ForcePerLengthUnits.TonneForcePerMeter:
            return f"""{self.tonnes_force_per_meter} tf/m"""
        
        if unit == ForcePerLengthUnits.TonneForcePerCentimeter:
            return f"""{self.tonnes_force_per_centimeter} tf/cm"""
        
        if unit == ForcePerLengthUnits.TonneForcePerMillimeter:
            return f"""{self.tonnes_force_per_millimeter} tf/mm"""
        
        if unit == ForcePerLengthUnits.PoundForcePerFoot:
            return f"""{self.pounds_force_per_foot} lbf/ft"""
        
        if unit == ForcePerLengthUnits.PoundForcePerInch:
            return f"""{self.pounds_force_per_inch} lbf/in"""
        
        if unit == ForcePerLengthUnits.PoundForcePerYard:
            return f"""{self.pounds_force_per_yard} lbf/yd"""
        
        if unit == ForcePerLengthUnits.KilopoundForcePerFoot:
            return f"""{self.kilopounds_force_per_foot} kipf/ft"""
        
        if unit == ForcePerLengthUnits.KilopoundForcePerInch:
            return f"""{self.kilopounds_force_per_inch} kipf/in"""
        
        if unit == ForcePerLengthUnits.NanonewtonPerMeter:
            return f"""{self.nanonewtons_per_meter} """
        
        if unit == ForcePerLengthUnits.MicronewtonPerMeter:
            return f"""{self.micronewtons_per_meter} """
        
        if unit == ForcePerLengthUnits.MillinewtonPerMeter:
            return f"""{self.millinewtons_per_meter} """
        
        if unit == ForcePerLengthUnits.CentinewtonPerMeter:
            return f"""{self.centinewtons_per_meter} """
        
        if unit == ForcePerLengthUnits.DecinewtonPerMeter:
            return f"""{self.decinewtons_per_meter} """
        
        if unit == ForcePerLengthUnits.DecanewtonPerMeter:
            return f"""{self.decanewtons_per_meter} """
        
        if unit == ForcePerLengthUnits.KilonewtonPerMeter:
            return f"""{self.kilonewtons_per_meter} """
        
        if unit == ForcePerLengthUnits.MeganewtonPerMeter:
            return f"""{self.meganewtons_per_meter} """
        
        if unit == ForcePerLengthUnits.NanonewtonPerCentimeter:
            return f"""{self.nanonewtons_per_centimeter} """
        
        if unit == ForcePerLengthUnits.MicronewtonPerCentimeter:
            return f"""{self.micronewtons_per_centimeter} """
        
        if unit == ForcePerLengthUnits.MillinewtonPerCentimeter:
            return f"""{self.millinewtons_per_centimeter} """
        
        if unit == ForcePerLengthUnits.CentinewtonPerCentimeter:
            return f"""{self.centinewtons_per_centimeter} """
        
        if unit == ForcePerLengthUnits.DecinewtonPerCentimeter:
            return f"""{self.decinewtons_per_centimeter} """
        
        if unit == ForcePerLengthUnits.DecanewtonPerCentimeter:
            return f"""{self.decanewtons_per_centimeter} """
        
        if unit == ForcePerLengthUnits.KilonewtonPerCentimeter:
            return f"""{self.kilonewtons_per_centimeter} """
        
        if unit == ForcePerLengthUnits.MeganewtonPerCentimeter:
            return f"""{self.meganewtons_per_centimeter} """
        
        if unit == ForcePerLengthUnits.NanonewtonPerMillimeter:
            return f"""{self.nanonewtons_per_millimeter} """
        
        if unit == ForcePerLengthUnits.MicronewtonPerMillimeter:
            return f"""{self.micronewtons_per_millimeter} """
        
        if unit == ForcePerLengthUnits.MillinewtonPerMillimeter:
            return f"""{self.millinewtons_per_millimeter} """
        
        if unit == ForcePerLengthUnits.CentinewtonPerMillimeter:
            return f"""{self.centinewtons_per_millimeter} """
        
        if unit == ForcePerLengthUnits.DecinewtonPerMillimeter:
            return f"""{self.decinewtons_per_millimeter} """
        
        if unit == ForcePerLengthUnits.DecanewtonPerMillimeter:
            return f"""{self.decanewtons_per_millimeter} """
        
        if unit == ForcePerLengthUnits.KilonewtonPerMillimeter:
            return f"""{self.kilonewtons_per_millimeter} """
        
        if unit == ForcePerLengthUnits.MeganewtonPerMillimeter:
            return f"""{self.meganewtons_per_millimeter} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ForcePerLengthUnits = ForcePerLengthUnits.NewtonPerMeter) -> string:
        """
        Get ForcePerLength unit abbreviation.
        Note! the default abbreviation for ForcePerLength is NewtonPerMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ForcePerLengthUnits.NewtonPerMeter:
            return """N/m"""
        
        if unit_abbreviation == ForcePerLengthUnits.NewtonPerCentimeter:
            return """N/cm"""
        
        if unit_abbreviation == ForcePerLengthUnits.NewtonPerMillimeter:
            return """N/mm"""
        
        if unit_abbreviation == ForcePerLengthUnits.KilogramForcePerMeter:
            return """kgf/m"""
        
        if unit_abbreviation == ForcePerLengthUnits.KilogramForcePerCentimeter:
            return """kgf/cm"""
        
        if unit_abbreviation == ForcePerLengthUnits.KilogramForcePerMillimeter:
            return """kgf/mm"""
        
        if unit_abbreviation == ForcePerLengthUnits.TonneForcePerMeter:
            return """tf/m"""
        
        if unit_abbreviation == ForcePerLengthUnits.TonneForcePerCentimeter:
            return """tf/cm"""
        
        if unit_abbreviation == ForcePerLengthUnits.TonneForcePerMillimeter:
            return """tf/mm"""
        
        if unit_abbreviation == ForcePerLengthUnits.PoundForcePerFoot:
            return """lbf/ft"""
        
        if unit_abbreviation == ForcePerLengthUnits.PoundForcePerInch:
            return """lbf/in"""
        
        if unit_abbreviation == ForcePerLengthUnits.PoundForcePerYard:
            return """lbf/yd"""
        
        if unit_abbreviation == ForcePerLengthUnits.KilopoundForcePerFoot:
            return """kipf/ft"""
        
        if unit_abbreviation == ForcePerLengthUnits.KilopoundForcePerInch:
            return """kipf/in"""
        
        if unit_abbreviation == ForcePerLengthUnits.NanonewtonPerMeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.MicronewtonPerMeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.MillinewtonPerMeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.CentinewtonPerMeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.DecinewtonPerMeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.DecanewtonPerMeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.KilonewtonPerMeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.MeganewtonPerMeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.NanonewtonPerCentimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.MicronewtonPerCentimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.MillinewtonPerCentimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.CentinewtonPerCentimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.DecinewtonPerCentimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.DecanewtonPerCentimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.KilonewtonPerCentimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.MeganewtonPerCentimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.NanonewtonPerMillimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.MicronewtonPerMillimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.MillinewtonPerMillimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.CentinewtonPerMillimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.DecinewtonPerMillimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.DecanewtonPerMillimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.KilonewtonPerMillimeter:
            return """"""
        
        if unit_abbreviation == ForcePerLengthUnits.MeganewtonPerMillimeter:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for +: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return ForcePerLength(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for *: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return ForcePerLength(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for -: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return ForcePerLength(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for /: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return ForcePerLength(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for %: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return ForcePerLength(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for **: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return ForcePerLength(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for ==: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for <: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for >: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for <=: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ForcePerLength):
            raise TypeError("unsupported operand type(s) for >=: 'ForcePerLength' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class MolarFlowUnits(Enum):
        """
            MolarFlowUnits enumeration
        """
        
        MolePerSecond = 'mole_per_second'
        """
            
        """
        
        MolePerMinute = 'mole_per_minute'
        """
            
        """
        
        MolePerHour = 'mole_per_hour'
        """
            
        """
        
        PoundMolePerSecond = 'pound_mole_per_second'
        """
            
        """
        
        PoundMolePerMinute = 'pound_mole_per_minute'
        """
            
        """
        
        PoundMolePerHour = 'pound_mole_per_hour'
        """
            
        """
        
        KilomolePerSecond = 'kilomole_per_second'
        """
            
        """
        
        KilomolePerMinute = 'kilomole_per_minute'
        """
            
        """
        
        KilomolePerHour = 'kilomole_per_hour'
        """
            
        """
        

class MolarFlow:
    """
    Molar flow is the ratio of the amount of substance change to the time during which the change occurred (value of amount of substance changes per unit time).

    Args:
        value (float): The value.
        from_unit (MolarFlowUnits): The MolarFlow unit to create from, The default unit is MolePerSecond
    """
    def __init__(self, value: float, from_unit: MolarFlowUnits = MolarFlowUnits.MolePerSecond):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__moles_per_second = None
        
        self.__moles_per_minute = None
        
        self.__moles_per_hour = None
        
        self.__pound_moles_per_second = None
        
        self.__pound_moles_per_minute = None
        
        self.__pound_moles_per_hour = None
        
        self.__kilomoles_per_second = None
        
        self.__kilomoles_per_minute = None
        
        self.__kilomoles_per_hour = None
        

    def __convert_from_base(self, from_unit: MolarFlowUnits) -> float:
        value = self.__value
        
        if from_unit == MolarFlowUnits.MolePerSecond:
            return (value)
        
        if from_unit == MolarFlowUnits.MolePerMinute:
            return (value * 60)
        
        if from_unit == MolarFlowUnits.MolePerHour:
            return (value * 3600)
        
        if from_unit == MolarFlowUnits.PoundMolePerSecond:
            return (value / 453.59237)
        
        if from_unit == MolarFlowUnits.PoundMolePerMinute:
            return ((value / 453.59237) * 60)
        
        if from_unit == MolarFlowUnits.PoundMolePerHour:
            return ((value / 453.59237) * 3600)
        
        if from_unit == MolarFlowUnits.KilomolePerSecond:
            return ((value) / 1000.0)
        
        if from_unit == MolarFlowUnits.KilomolePerMinute:
            return ((value * 60) / 1000.0)
        
        if from_unit == MolarFlowUnits.KilomolePerHour:
            return ((value * 3600) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: MolarFlowUnits) -> float:
        
        if to_unit == MolarFlowUnits.MolePerSecond:
            return (value)
        
        if to_unit == MolarFlowUnits.MolePerMinute:
            return (value / 60)
        
        if to_unit == MolarFlowUnits.MolePerHour:
            return (value / 3600)
        
        if to_unit == MolarFlowUnits.PoundMolePerSecond:
            return (value * 453.59237)
        
        if to_unit == MolarFlowUnits.PoundMolePerMinute:
            return ((value * 453.59237) / 60)
        
        if to_unit == MolarFlowUnits.PoundMolePerHour:
            return ((value * 453.59237) / 3600)
        
        if to_unit == MolarFlowUnits.KilomolePerSecond:
            return ((value) * 1000.0)
        
        if to_unit == MolarFlowUnits.KilomolePerMinute:
            return ((value / 60) * 1000.0)
        
        if to_unit == MolarFlowUnits.KilomolePerHour:
            return ((value / 3600) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_moles_per_second(moles_per_second: float):
        """
        Create a new instance of MolarFlow from a value in moles_per_second.

        

        :param meters: The MolarFlow value in moles_per_second.
        :type moles_per_second: float
        :return: A new instance of MolarFlow.
        :rtype: MolarFlow
        """
        return MolarFlow(moles_per_second, MolarFlowUnits.MolePerSecond)

    
    @staticmethod
    def from_moles_per_minute(moles_per_minute: float):
        """
        Create a new instance of MolarFlow from a value in moles_per_minute.

        

        :param meters: The MolarFlow value in moles_per_minute.
        :type moles_per_minute: float
        :return: A new instance of MolarFlow.
        :rtype: MolarFlow
        """
        return MolarFlow(moles_per_minute, MolarFlowUnits.MolePerMinute)

    
    @staticmethod
    def from_moles_per_hour(moles_per_hour: float):
        """
        Create a new instance of MolarFlow from a value in moles_per_hour.

        

        :param meters: The MolarFlow value in moles_per_hour.
        :type moles_per_hour: float
        :return: A new instance of MolarFlow.
        :rtype: MolarFlow
        """
        return MolarFlow(moles_per_hour, MolarFlowUnits.MolePerHour)

    
    @staticmethod
    def from_pound_moles_per_second(pound_moles_per_second: float):
        """
        Create a new instance of MolarFlow from a value in pound_moles_per_second.

        

        :param meters: The MolarFlow value in pound_moles_per_second.
        :type pound_moles_per_second: float
        :return: A new instance of MolarFlow.
        :rtype: MolarFlow
        """
        return MolarFlow(pound_moles_per_second, MolarFlowUnits.PoundMolePerSecond)

    
    @staticmethod
    def from_pound_moles_per_minute(pound_moles_per_minute: float):
        """
        Create a new instance of MolarFlow from a value in pound_moles_per_minute.

        

        :param meters: The MolarFlow value in pound_moles_per_minute.
        :type pound_moles_per_minute: float
        :return: A new instance of MolarFlow.
        :rtype: MolarFlow
        """
        return MolarFlow(pound_moles_per_minute, MolarFlowUnits.PoundMolePerMinute)

    
    @staticmethod
    def from_pound_moles_per_hour(pound_moles_per_hour: float):
        """
        Create a new instance of MolarFlow from a value in pound_moles_per_hour.

        

        :param meters: The MolarFlow value in pound_moles_per_hour.
        :type pound_moles_per_hour: float
        :return: A new instance of MolarFlow.
        :rtype: MolarFlow
        """
        return MolarFlow(pound_moles_per_hour, MolarFlowUnits.PoundMolePerHour)

    
    @staticmethod
    def from_kilomoles_per_second(kilomoles_per_second: float):
        """
        Create a new instance of MolarFlow from a value in kilomoles_per_second.

        

        :param meters: The MolarFlow value in kilomoles_per_second.
        :type kilomoles_per_second: float
        :return: A new instance of MolarFlow.
        :rtype: MolarFlow
        """
        return MolarFlow(kilomoles_per_second, MolarFlowUnits.KilomolePerSecond)

    
    @staticmethod
    def from_kilomoles_per_minute(kilomoles_per_minute: float):
        """
        Create a new instance of MolarFlow from a value in kilomoles_per_minute.

        

        :param meters: The MolarFlow value in kilomoles_per_minute.
        :type kilomoles_per_minute: float
        :return: A new instance of MolarFlow.
        :rtype: MolarFlow
        """
        return MolarFlow(kilomoles_per_minute, MolarFlowUnits.KilomolePerMinute)

    
    @staticmethod
    def from_kilomoles_per_hour(kilomoles_per_hour: float):
        """
        Create a new instance of MolarFlow from a value in kilomoles_per_hour.

        

        :param meters: The MolarFlow value in kilomoles_per_hour.
        :type kilomoles_per_hour: float
        :return: A new instance of MolarFlow.
        :rtype: MolarFlow
        """
        return MolarFlow(kilomoles_per_hour, MolarFlowUnits.KilomolePerHour)

    
    @property
    def moles_per_second(self) -> float:
        """
        
        """
        if self.__moles_per_second != None:
            return self.__moles_per_second
        self.__moles_per_second = self.__convert_from_base(MolarFlowUnits.MolePerSecond)
        return self.__moles_per_second

    
    @property
    def moles_per_minute(self) -> float:
        """
        
        """
        if self.__moles_per_minute != None:
            return self.__moles_per_minute
        self.__moles_per_minute = self.__convert_from_base(MolarFlowUnits.MolePerMinute)
        return self.__moles_per_minute

    
    @property
    def moles_per_hour(self) -> float:
        """
        
        """
        if self.__moles_per_hour != None:
            return self.__moles_per_hour
        self.__moles_per_hour = self.__convert_from_base(MolarFlowUnits.MolePerHour)
        return self.__moles_per_hour

    
    @property
    def pound_moles_per_second(self) -> float:
        """
        
        """
        if self.__pound_moles_per_second != None:
            return self.__pound_moles_per_second
        self.__pound_moles_per_second = self.__convert_from_base(MolarFlowUnits.PoundMolePerSecond)
        return self.__pound_moles_per_second

    
    @property
    def pound_moles_per_minute(self) -> float:
        """
        
        """
        if self.__pound_moles_per_minute != None:
            return self.__pound_moles_per_minute
        self.__pound_moles_per_minute = self.__convert_from_base(MolarFlowUnits.PoundMolePerMinute)
        return self.__pound_moles_per_minute

    
    @property
    def pound_moles_per_hour(self) -> float:
        """
        
        """
        if self.__pound_moles_per_hour != None:
            return self.__pound_moles_per_hour
        self.__pound_moles_per_hour = self.__convert_from_base(MolarFlowUnits.PoundMolePerHour)
        return self.__pound_moles_per_hour

    
    @property
    def kilomoles_per_second(self) -> float:
        """
        
        """
        if self.__kilomoles_per_second != None:
            return self.__kilomoles_per_second
        self.__kilomoles_per_second = self.__convert_from_base(MolarFlowUnits.KilomolePerSecond)
        return self.__kilomoles_per_second

    
    @property
    def kilomoles_per_minute(self) -> float:
        """
        
        """
        if self.__kilomoles_per_minute != None:
            return self.__kilomoles_per_minute
        self.__kilomoles_per_minute = self.__convert_from_base(MolarFlowUnits.KilomolePerMinute)
        return self.__kilomoles_per_minute

    
    @property
    def kilomoles_per_hour(self) -> float:
        """
        
        """
        if self.__kilomoles_per_hour != None:
            return self.__kilomoles_per_hour
        self.__kilomoles_per_hour = self.__convert_from_base(MolarFlowUnits.KilomolePerHour)
        return self.__kilomoles_per_hour

    
    def to_string(self, unit: MolarFlowUnits = MolarFlowUnits.MolePerSecond) -> string:
        """
        Format the MolarFlow to string.
        Note! the default format for MolarFlow is MolePerSecond.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == MolarFlowUnits.MolePerSecond:
            return f"""{self.moles_per_second} mol/s"""
        
        if unit == MolarFlowUnits.MolePerMinute:
            return f"""{self.moles_per_minute} mol/min"""
        
        if unit == MolarFlowUnits.MolePerHour:
            return f"""{self.moles_per_hour} kmol/h"""
        
        if unit == MolarFlowUnits.PoundMolePerSecond:
            return f"""{self.pound_moles_per_second} lbmol/s"""
        
        if unit == MolarFlowUnits.PoundMolePerMinute:
            return f"""{self.pound_moles_per_minute} lbmol/min"""
        
        if unit == MolarFlowUnits.PoundMolePerHour:
            return f"""{self.pound_moles_per_hour} lbmol/h"""
        
        if unit == MolarFlowUnits.KilomolePerSecond:
            return f"""{self.kilomoles_per_second} """
        
        if unit == MolarFlowUnits.KilomolePerMinute:
            return f"""{self.kilomoles_per_minute} """
        
        if unit == MolarFlowUnits.KilomolePerHour:
            return f"""{self.kilomoles_per_hour} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: MolarFlowUnits = MolarFlowUnits.MolePerSecond) -> string:
        """
        Get MolarFlow unit abbreviation.
        Note! the default abbreviation for MolarFlow is MolePerSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == MolarFlowUnits.MolePerSecond:
            return """mol/s"""
        
        if unit_abbreviation == MolarFlowUnits.MolePerMinute:
            return """mol/min"""
        
        if unit_abbreviation == MolarFlowUnits.MolePerHour:
            return """kmol/h"""
        
        if unit_abbreviation == MolarFlowUnits.PoundMolePerSecond:
            return """lbmol/s"""
        
        if unit_abbreviation == MolarFlowUnits.PoundMolePerMinute:
            return """lbmol/min"""
        
        if unit_abbreviation == MolarFlowUnits.PoundMolePerHour:
            return """lbmol/h"""
        
        if unit_abbreviation == MolarFlowUnits.KilomolePerSecond:
            return """"""
        
        if unit_abbreviation == MolarFlowUnits.KilomolePerMinute:
            return """"""
        
        if unit_abbreviation == MolarFlowUnits.KilomolePerHour:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for +: 'MolarFlow' and '{}'".format(type(other).__name__))
        return MolarFlow(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for *: 'MolarFlow' and '{}'".format(type(other).__name__))
        return MolarFlow(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for -: 'MolarFlow' and '{}'".format(type(other).__name__))
        return MolarFlow(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for /: 'MolarFlow' and '{}'".format(type(other).__name__))
        return MolarFlow(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for %: 'MolarFlow' and '{}'".format(type(other).__name__))
        return MolarFlow(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for **: 'MolarFlow' and '{}'".format(type(other).__name__))
        return MolarFlow(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for ==: 'MolarFlow' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for <: 'MolarFlow' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for >: 'MolarFlow' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for <=: 'MolarFlow' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, MolarFlow):
            raise TypeError("unsupported operand type(s) for >=: 'MolarFlow' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value